//
//  Sample.m
//  SiiLibSample
//

#import "Sample.h"
#import "SIISmartLabelManager.h"

BOOL _printerDiscoveryCompletion;
NSString *_resultMessage;
SIIPrinterManager *_printer;
SIISmartLabelManager *_label;

@implementation Sample

+ (void)InitialSetting:(ViewController *)view
{
    _printerDiscoveryCompletion = NO;
    _resultMessage = @"";
    _printer = [[SIIPrinterManager alloc] init];
    _printer.delegate = view;
    _label = [[SIISmartLabelManager alloc] init];
}

+ (BOOL)connectSample:(NSInteger)model address:(NSString *)address type:(NSInteger)type
{
    @try {
        [_printer connect:model address:address portType:type];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)disconnectSample
{
    @try {
        [_printer disconnect];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printPageModeSample
{
    @try {
        @try {
            [_printer enterPageMode];
            [_printer setPageModeArea:0 y:0 width:576 height:355];
            [_printer printPageModeRectangle:0 startY:0 endX:575 endY:344 lineStyle:SII_PM_LINESTYLE_THIN];
            [_printer printPageModeRectangle:7 startY:7 endX:567 endY:336 lineStyle:SII_PM_LINESTYLE_THIN];
            [_printer printPageModeLine:404 startY:11 endX:404 endY:334 lineStyle:SII_PM_LINESTYLE_THIN];
            [_printer printPageModeText:21 startY:37 text:@"NO.123456789"];
            [_printer printPageModeText:212 startY:330 text:@"Date 2020-01-01"];
            NSString *filePath = [[NSBundle mainBundle] pathForResource:@"TicketImage" ofType:@"jpg"];
            [_printer printPageModeImageFile:10 startY:212 fileName:filePath dithering:SII_PM_DITHERING_DISABLE];
            [_printer setPageModeArea:404 y:0 width:163 height:345];
            [_printer setPageModeDirection:SII_PM_DIRECTION_BOTTOM_TO_TOP];
            NSData *barccodeData = [@"{B123456789" dataUsingEncoding:NSASCIIStringEncoding];
            [_printer printPageModeBarcode:20 startY:132 barcodeSymbol:SII_PM_BARCODE_CODE128 data:barccodeData moduleSize:SII_PM_BARCODE_MODULE_WIDTH_2 moduleHeight:80 hriPosition:SII_PM_HRI_POSITION_ABOVE hriFont:SII_PM_FONT_A];
            [_printer printPageMode:SII_PM_CUT_PARTIAL];
            _resultMessage = @"Succeeded";
            return YES;
        }
        @catch (SIIPrinterException *e) {
            _resultMessage = [self getErrorMessage:e.errorCode];
            return NO;
        }
    }
    @finally {
        @try {
            [_printer exitPageMode];
        }
        @catch (SIIPrinterException *e) {
        }
    }
}

+ (BOOL)sendTextSample:(NSString *)text
{
    @try {
        [_printer sendText:text];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)sendTextExSample:(NSString *)text
{
    @try {
        [_printer sendTextEx:text bold:SII_PM_BOLD underline:SII_PM_UNDERLINE_1 font:SII_PM_FONT_A scale:SII_PM_VARTICAL_2_HORIZONTAL_2];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printBarcodeSample
{
    BOOL success = YES;
    if( ![self barcode_upca]){ success = NO; }
    if( ![self barcode_upce]){ success = NO; }
    if( ![self barcode_ean13]){ success = NO; }
    if( ![self barcode_ean8]){ success = NO; }
    if( ![self barcode_code39]){ success = NO; }
    if (_printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S245 && _printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S445) {
        if( ![self barcode_code93]){ success = NO; }
    }
    if( ![self barcode_code128]){ success = NO; }
    if( ![self barcode_itf]){ success = NO; }
    if( ![self barcode_codabar]){ success = NO; }
    if (_printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S245 && _printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S445) {
        if( ![self barcode_ean13_addon]){ success = NO; }
    }
    if (_printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S245 && _printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S445
        && _printer.printerModel !=  SII_PM_PRINTER_MODEL_RP_D10 && _printer.printerModel !=  SII_PM_PRINTER_MODEL_RP_E10) {
        if( ![self barcode_gs1_omini_directional]){ success = NO; }
        if( ![self barcode_gs1_truncated]){ success = NO; }
        if( ![self barcode_gs1_limited]){ success = NO; }
        if( ![self barcode_gs1_expanded]){ success = NO; }
    }

    if(success) {
        _resultMessage = @"Succeeded";
        return YES;
    } else {
        return NO;
    }
}

+ (BOOL)barcode_upca
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_UPC_A;
    NSString *text = @"12345678901";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_upce
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_UPC_E;
    NSString *text = @"01234500005";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_ean13
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_EAN13;
    NSString *text = @"123456789012";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_ean8
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_EAN8;
    NSString *text = @"1234567";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_code39
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_CODE39;
    NSString *text = @"1234";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_code93
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_CODE93;
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;
    unsigned char dataArry[8] = {0x01, 0x02, 0x03, 0x04, 0x0b, 0x0c, 0x0d, 0xff};
    NSData *data = [NSData dataWithBytes:dataArry length:sizeof(dataArry)];

    @try {
        [_printer printBarcode:barcodeSymbol data:data moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_code128
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_CODE128;
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;
    unsigned char dataArry[6] = {0x67, 0x01, 0x02, 0x03, 0x04, 0x67};
    NSData *data = [NSData dataWithBytes:dataArry length:sizeof(dataArry)];

    @try {
        [_printer printBarcode:barcodeSymbol data:data moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_itf
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_ITF;
    NSString *text = @"12345678";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_codabar
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_CODABAR;
    NSString *text = @"A123456A";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_ean13_addon
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_EAN13_ADDON;
    NSString *text = @"12345678901234";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_2;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_gs1_omini_directional
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_GS1_OMNI_DIRECTIONAL;
    NSString *text = @"1234567890123";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 99;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_gs1_truncated
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_GS1_TRUNCATED;
    NSString *text = @"1234567890123";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_gs1_limited
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_GS1_TRUNCATED;
    NSString *text = @"1234567890123";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 50;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)barcode_gs1_expanded
{
    BarcodeSymbol barcodeSymbol = SII_PM_BARCODE_GS1_EXPANDED;
    NSString *text = @"123456";
    ModuleSize moduleSize = SII_PM_BARCODE_MODULE_WIDTH_3;
    NSInteger height = 102;
    HriPosition hriPosition = SII_PM_HRI_POSITION_ABOVE;
    CharacterFont hriFont = SII_PM_FONT_A;
    PrintAlignment alignment = SII_PM_ALIGNMENT_LEFT;

    @try {
        [_printer printBarcode:barcodeSymbol text:text moduleSize:moduleSize moduleHeight:height hriPosition:hriPosition hriFont:hriFont alignment:alignment];
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printPDF417Sample
{
    @try {
        [_printer printPDF417:@"123456789ABCD" errorCorrection:SII_PM_PDF417_ERROR_CORRECTION_3 row:0 column:0 moduleSize:SII_PM_PDF417_MODULE_WIDTH_3 moduleHeight:10 alignment:SII_PM_ALIGNMENT_LEFT pdf417Symbol:SII_PM_PDF417_STANDARD];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printQRcodeSample
{
    @try {
        [_printer printQRcode:@"123456789ABCD" errorCorrection:SII_PM_QR_ERROR_CORRECTION_M moduleSize:SII_PM_QR_MODULE_SIZE_6 alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printDataMatrixSample
{
    @try {
        [_printer printDataMatrix:@"0123456789" dataMatrixModule:SII_PM_DATA_MATRIX_AUTO moduleSize:SII_PM_DATAMATRIX_MODULE_SIZE_6 alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printMaxiCodeSample
{
    @try {
        [_printer printMaxiCode:@"122333444455555ABC0123456789DEF" maxiCodeMode:SII_PM_MAXI_CODE_2 alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printGS1DataBarStackedSample
{
    @try {
        [_printer printGS1DataBarStacked:@"1230123456789" moduleSize:SII_PM_GS1DATABAR_MODULE_SIZE_6 alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printGS1DataBarStackedOmnidirectionalSample
{
    @try {
        [_printer printGS1DataBarStackedOmnidirectional:@"1230123456789" moduleHeight:33 moduleSize:SII_PM_GS1DATABAR_MODULE_SIZE_6 alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printGS1DataBarExpandedStackedSample
{
    @try {
        [_printer printGS1DataBarExpandedStacked:@"ABCDEFG" column:2 moduleSize:SII_PM_GS1DATABAR_MODULE_SIZE_6 alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printAztecCodeSample
{
    @try {
        [_printer printAztecCode:@"1234567890" layer:0 errorCorrection:0 moduleSize:SII_PM_AZTECCODE_MODULE_SIZE_6 aztecSymbol:SII_PM_AZTECCODE_COMPACT alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)cutPaperSample:(NSInteger)cuttingMethod
{
    @try {
        [_printer cutPaper:cuttingMethod];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)feedPositionSample
{
    @try {
        [_printer feedPosition:SII_PM_FEED_CUTTER];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)openDrawerSample
{
    @try {
        [_printer openDrawer:SII_PM_DRAWER_1 onOffTime:SII_PM_ON_OFF_TIME_500];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)buzzerSample
{
    @try {
        [_printer buzzer:100 offTime:100];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)externalBuzzerSample
{
    @try {
        [_printer externalBuzzer:SII_PM_BUZZER_PATTERN_1 buzzerCount:1];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)sendBinarySample:(NSData *)data
{
    @try {
        [_printer sendBinary:data];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)sendDataFileSample:(NSString *)filePath
{
    @try {
        [_printer sendDataFile:filePath alignment:SII_PM_ALIGNMENT_LEFT];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)getStatusSample
{
    @try {
        NSInteger val[1];
        [_printer getStatus:val];
        _resultMessage = [NSString stringWithFormat:@"getStatus:0x%02lX", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)abortSample
{
    @try {
        [_printer abort];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerLogoSample:(NSString *)filePath
{
    NSString *logoid = @"$$";

    if(_printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || _printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445) {
        logoid = @"2";
    }

    @try {
        [_printer registerLogo:filePath logoId:logoid dithering:SII_PM_DITHERING_ERRORDIFFUSION];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printLogoSample
{
    NSString *logoid = @"$$";

    if(_printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || _printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445) {
        logoid = @"2";
    }

    @try {
        [_printer printLogo:logoid];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterLogoSample
{
    NSString *logoid = @"$$";

    if(_printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || _printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445) {
        logoid = @"2";
    }

    @try {
        [_printer unregisterLogo:logoid];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerStyleSheetSample:(NSString *)filePath
{
    @try {
        [_printer registerStyleSheet:filePath cssId:1];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterStyleSheetSample
{
    @try {
        [_printer unregisterStyleSheet:1];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)resetPrinterSample
{
    @try {
        [_printer resetPrinter];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)getPrinterResponseSample:(NSInteger)responseId
{
    if (responseId == SII_PM_PRINTER_RESPONSE_REQUEST) {
        return [self response_request];
    } else if (responseId == SII_PM_PRINTER_RESPONSE_USER_AREA) {
        return [self response_userarea];
    } else if (responseId == SII_PM_PRINTER_RESPONSE_ARRANGE_USER_AREA) {
        return [self response_arrangeuserarea];
    } else if (responseId == SII_PM_PRINTER_RESPONSE_NV_GRAPHICS) {
        return [self response_nvgraphics];
    } else if (responseId == SII_PM_PRINTER_RESPONSE_KEY_CODE) {
        return [self response_keycode];
    } else if (responseId == SII_PM_PRINTER_RESPONSE_BATTERY_STATUS) {
        return [self response_batterystatus];
    } else {
         _resultMessage = @"responseId invalid\n";
        return NO;
    }
}

+ (BOOL)response_request
{
    @try {
        UInt8 param[1] = { 0x01 };
        NSInteger val[1];
        [_printer getPrinterResponse:SII_PM_PRINTER_RESPONSE_REQUEST param:[NSData dataWithBytes:param length:sizeof(param)] response:val];
        _resultMessage = [NSString stringWithFormat:@"REQUEST:0x%02lX", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_userarea
{
    @try {
        NSInteger val[1];
        [_printer getPrinterResponse:SII_PM_PRINTER_RESPONSE_USER_AREA param:nil response:val];
        _resultMessage = [NSString stringWithFormat:@"USER_AREA:%ld", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_arrangeuserarea
{
    @try {
        NSInteger val[1];
        [_printer getPrinterResponse:SII_PM_PRINTER_RESPONSE_ARRANGE_USER_AREA param:nil response:val];
        _resultMessage = [NSString stringWithFormat:@"ARRANGE_USER_AREA:%ld", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_nvgraphics
{
    @try {
        NSInteger val[1];
        [_printer getPrinterResponse:SII_PM_PRINTER_RESPONSE_NV_GRAPHICS param:nil response:val];
        _resultMessage = [NSString stringWithFormat:@"NV_GRAPHICS:%ld", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_keycode
{
    @try {
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getPrinterResponse:SII_PM_PRINTER_RESPONSE_KEY_CODE param:nil response:(__bridge void *)(ret)];
        NSString *resultText = @"KEY_CODE:";
        for (int i=0; i<ret.count; i++) {
            resultText = [resultText stringByAppendingString:[NSString stringWithFormat:@"%@, ", [ret objectAtIndex:i]]];
        }
        _resultMessage = resultText;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_batterystatus
{
    @try {
        NSInteger val[1];
        [_printer getPrinterResponse:SII_PM_PRINTER_RESPONSE_BATTERY_STATUS param:nil response:val];
        if (_printer.printerModel== SII_PM_PRINTER_MODEL_MP_B20 || _printer.printerModel== SII_PM_PRINTER_MODEL_MP_B30 || _printer.printerModel== SII_PM_PRINTER_MODEL_MP_B30L) {
            if (val[0]==SII_PM_BATTERY_STATUS_FULL) {
                _resultMessage = @"BATTERY_STATUS:FULL";
            } else if (val[0]==SII_PM_BATTERY_STATUS_MIDDLE) {
                _resultMessage = @"BATTERY_STATUS:MIDDLE";
            } else if (val[0]==SII_PM_BATTERY_STATUS_LOW) {
                _resultMessage = @"BATTERY_STATUS:LOW";
            } else if (val[0]==SII_PM_BATTERY_STATUS_EMPTY) {
                _resultMessage = @"BATTERY_STATUS:EMPTY";
            } else {
                _resultMessage = [NSString stringWithFormat:@"BATTERY_STATUS:%ld", (long)val[0]];
            }
        } else if (_printer.printerModel== SII_PM_PRINTER_MODEL_DPU_S245 || _printer.printerModel== SII_PM_PRINTER_MODEL_DPU_S445) {
            if (val[0]==0){
                _resultMessage = @"BATTERY_STATUS:8.0 V or higher";
            } else if (val[0]==1) {
                _resultMessage = @"BATTERY_STATUS:7.5 V to 8.0 V";
            } else if (val[0]==2) {
                _resultMessage = @"BATTERY_STATUS:7.0 V to 7.5 V";
            } else if (val[0]==3) {
                _resultMessage = @"BATTERY_STATUS:Lower than 7.0 V";
            } else {
                _resultMessage = [NSString stringWithFormat:@"BATTERY_STATUS:%ld", (long)val[0]];
            }
        } else {
            _resultMessage = [NSString stringWithFormat:@"BATTERY_STATUS:%ld", (long)val[0]];
        }
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (void)startLanDiscoveryPrinterSample:(NSInteger)retryCount timeout:(NSInteger)timeout
{
    _printerDiscoveryCompletion = NO;

    [_printer startDiscoveryPrinter:retryCount timeout:timeout completion:^(NSArray *printerList) {
        [self performSelectorOnMainThread:@selector(setPrinterDiscoveryCompletion) withObject:nil waitUntilDone:NO];
    }];
    
    _resultMessage = @"Succeeded";
}

+ (void)setPrinterDiscoveryCompletion
{
    _printerDiscoveryCompletion = YES;
}

+ (BOOL)getPrinterDiscoveryCompletion
{
    return _printerDiscoveryCompletion;
}

+ (void)startBluetoothDiscoveryPrinterSample
{
    [_printer startDiscoveryPrinter:nil completion:^(NSError *error) {}];
}

+ (void)cancelDiscoveryPrinterSample
{
    [_printer cancelDiscoveryPrinter];
    _resultMessage = @"Succeeded";
}

+ (NSArray *)getFoundPrinterSample
{
    return [_printer getFoundPrinter];
}

+ (BOOL)getVersionSample
{
    _resultMessage = [_printer getVersion];
    return YES;
}

+ (BOOL)controlTransactionSample:(NSInteger)transactionFunction
{
    @try {
        [_printer controlTransaction:transactionFunction];
        _resultMessage = @"Succeeded";
        return YES;
    } @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (NSInteger)get_sendTimeoutSample
{
    NSInteger timeout = _printer.sendTimeout;

    return timeout;
}

+ (void)set_sendTimeoutSample:(NSInteger)time
{
    _printer.sendTimeout = time;

    if (_printer.sendTimeout == time) {
        _resultMessage = @"Succeeded";
    } else {
        _resultMessage = @"sendTimeout is rounded";
    }
}

+ (NSInteger)get_receiveTimeoutSample
{
    NSInteger timeout = _printer.receiveTimeout;

    return timeout;
}

+ (void)set_receiveTimeoutSample:(NSInteger)time
{
    _printer.receiveTimeout = time;

    if (_printer.receiveTimeout == time) {
        _resultMessage = @"Succeeded";
    } else {
        _resultMessage = @"receiveTimeout is rounded";
    }
}

+ (void)get_internationalCharacterSample
{
    NSInteger internationalCharacter = _printer.internationalCharacter;

    if(internationalCharacter == SII_PM_COUNTRY_USA) {
        _resultMessage = @"internationalCharacter:\nUSA";
    } else if (internationalCharacter == SII_PM_COUNTRY_FRANCE) {
        _resultMessage = @"internationalCharacter:\nFRANCE";
    } else if (internationalCharacter == SII_PM_COUNTRY_GERMANY) {
        _resultMessage = @"internationalCharacter:\nGERMANY";
    } else if (internationalCharacter == SII_PM_COUNTRY_ENGLAND) {
        _resultMessage = @"internationalCharacter:\nENGLAND";
    } else if (internationalCharacter == SII_PM_COUNTRY_DENMARK_1) {
        _resultMessage = @"internationalCharacter:\nDENMARK_1";
    } else if (internationalCharacter == SII_PM_COUNTRY_SWEDEN) {
        _resultMessage = @"internationalCharacter:\nSWEDEN";
    } else if (internationalCharacter == SII_PM_COUNTRY_ITALY) {
        _resultMessage = @"internationalCharacter:\nITALY";
    } else if (internationalCharacter == SII_PM_COUNTRY_SPAIN) {
        _resultMessage = @"internationalCharacter:\nSPAIN";
    } else if (internationalCharacter == SII_PM_COUNTRY_JAPAN) {
        _resultMessage = @"internationalCharacter:\nJAPAN";
    } else if (internationalCharacter == SII_PM_COUNTRY_NORWAY) {
        _resultMessage = @"internationalCharacter:\nNORWAY";
    } else if (internationalCharacter == SII_PM_COUNTRY_DENMARK_2) {
        _resultMessage = @"internationalCharacter:\nDENMARK_2";
    } else if (internationalCharacter == SII_PM_COUNTRY_SPAIN_2) {
        _resultMessage = @"internationalCharacter:\nSPAIN_2";
    } else if (internationalCharacter == SII_PM_COUNTRY_LATIN_AMERICA) {
        _resultMessage = @"internationalCharacter:\nLATIN_AMERICA";
    } else if (internationalCharacter == SII_PM_COUNTRY_ARABIA) {
        _resultMessage = @"internationalCharacter:\nARABIA";
    } else {
        _resultMessage = @"internationalCharacter is invalid";
    }
}

+ (void)set_internationalCharacterSample:(NSInteger)internationalCharacter
{
    _printer.internationalCharacter = internationalCharacter;

    if (_printer.internationalCharacter == internationalCharacter) {
        _resultMessage = @"Succeeded";
    } else {
        _resultMessage = @"Faile to set internationalCharacter";
    }
}

+ (void)get_codePageSample
{
    NSInteger codePage = _printer.codePage;

    if(codePage == SII_PM_CODE_PAGE_437) {
        _resultMessage = @"codePage:codePage 437";
    } else if (codePage == SII_PM_CODE_PAGE_KATAKANA) {
        _resultMessage = @"codePage:codePage KATAKANA";
    } else if (codePage == SII_PM_CODE_PAGE_850) {
        _resultMessage = @"codePage:codePage 850";
    } else if (codePage == SII_PM_CODE_PAGE_860) {
        _resultMessage = @"codePage:codePage 860";
    } else if (codePage == SII_PM_CODE_PAGE_863) {
        _resultMessage = @"codePage:codePage 863";
    } else if (codePage == SII_PM_CODE_PAGE_865) {
        _resultMessage = @"codePage:codePage 865";
    } else if (codePage == SII_PM_CODE_PAGE_857) {
        _resultMessage = @"codePage:codePage 857";
    } else if (codePage == SII_PM_CODE_PAGE_737) {
        _resultMessage = @"codePage:codePage 737";
    } else if (codePage == SII_PM_CODE_PAGE_1252) {
        _resultMessage = @"codePage:codePage 1252";
    } else if (codePage == SII_PM_CODE_PAGE_866) {
        _resultMessage = @"codePage:codePage 866";
    } else if (codePage == SII_PM_CODE_PAGE_852) {
        _resultMessage = @"codePage:codePage 852";
    } else if (codePage == SII_PM_CODE_PAGE_858) {
        _resultMessage = @"codePage:codePage 858";
    } else if (codePage == SII_PM_CODE_PAGE_855) {
        _resultMessage = @"codePage:codePage 855";
    } else if (codePage == SII_PM_CODE_PAGE_864) {
        _resultMessage = @"codePage:codePage 864";
    } else if (codePage == SII_PM_CODE_PAGE_1250) {
        _resultMessage = @"codePage:codePage 1250";
    } else if (codePage == SII_PM_CODE_PAGE_1251) {
        _resultMessage = @"codePage:codePage 1251";
    } else if (codePage == SII_PM_CODE_PAGE_1253) {
        _resultMessage = @"codePage:codePage 1253";
    } else if (codePage == SII_PM_CODE_PAGE_1254) {
        _resultMessage = @"codePage:codePage 1254";
    } else {
        _resultMessage = @"codePage is invalid";
    }
}

+ (void)set_codePageSample:(NSInteger)codePage
{
    _printer.codePage = codePage;

    if (_printer.codePage == codePage) {
        _resultMessage = @"Succeeded";
    } else {
        _resultMessage = @"Faile to set codePage";
    }
}

+ (void)get_printerModelSample
{
    NSInteger printerModel = _printer.printerModel;

    if(printerModel == SII_PM_PRINTER_MODEL_DPU_S445) {
        _resultMessage = @"printerModel:DPU-S445";
    } else if (printerModel == SII_PM_PRINTER_MODEL_DPU_S245) {
        _resultMessage = @"printerModel:DPU-S245";
    } else if (printerModel == SII_PM_PRINTER_MODEL_RP_E10) {
        _resultMessage = @"printerModel:RP-E10";
    } else if (printerModel == SII_PM_PRINTER_MODEL_RP_D10) {
        _resultMessage = @"printerModel:RP-D10";
    } else if (printerModel == SII_PM_PRINTER_MODEL_MP_B20) {
        _resultMessage = @"printerModel:MP-B20";
    } else if (printerModel == SII_PM_PRINTER_MODEL_MP_B30) {
        _resultMessage = @"printerModel:MP-B30";
    } else if (printerModel == SII_PM_PRINTER_MODEL_RP_F10) {
        _resultMessage = @"printerModel:RP-F10";
    } else if (printerModel == SII_PM_PRINTER_MODEL_MP_B30L) {
        _resultMessage = @"printerModel:MP-B30L";
    } else if (printerModel == SII_PM_PRINTER_MODEL_SLP720RT) {
        _resultMessage = @"printerModel:SLP720RT";
    } else {
        _resultMessage = @"printerModel:printer is not connected";
    }
}

+ (void)get_portTypeSample
{
    NSInteger portType = _printer.portType;

    if (portType == SII_PM_PRINTER_PORT_TYPE_BLUETOOTH) {
        _resultMessage = @"portType:Bluetooth";
    } else if (portType == SII_PM_PRINTER_PORT_TYPE_TCP) {
        _resultMessage = @"portType:TCP/IP";
    } else if (portType == SII_PM_PRINTER_PORT_TYPE_USB) {
        _resultMessage = @"portType:USB";
    } else {
        _resultMessage = @"portType:printer is not connected";
    }
}

+ (void)get_isConnectSample
{
    BOOL isConnect = _printer.isConnect;

    if(isConnect) {
        _resultMessage = @"isConnect:YES";
    } else {
        _resultMessage = @"isConnect:NO";
    }
}

+ (NSInteger)get_socketKeepingTimeSample
{
    NSInteger socketKeepingTime = _printer.socketKeepingTime;
    
    return socketKeepingTime;
}

+ (void)set_socketKeepingTimeSample:(NSInteger)time
{
    _printer.socketKeepingTime = time;

    if (_printer.socketKeepingTime == time) {
        _resultMessage = @"Succeeded";
    } else {
        _resultMessage = @"socketKeepingTime is rounded";
    }
}

+ (BOOL)defragmentSample
{
    @try {
        [_printer defragment:SII_PM_MEMORY_DISPLAY_USERMEMORY];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)initializeMemoryAreaSample
{
    @try {
        [_printer initializeMemoryArea:SII_PM_MEMORY_DISPLAY_USERMEMORY];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)showTemplateSample:(NSInteger)time_ms
{
    @try {
        [_printer showTemplate:time_ms];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)showSlideSample:(NSInteger)slideID time_ms:(NSInteger)time_ms
{
    @try {
        [_printer showSlide:slideID time_ms:time_ms];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)enterStandbyModeSample
{
    @try {
        [_printer enterStandbyMode];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)executeMacroSample:(NSInteger)macroID repeatCount:(NSInteger)repeatCount
{
    @try {
        [_printer executeMacro:macroID repeatCount:repeatCount];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)turnOnScreenSample:(BOOL)isOn
{
    @try {
        [_printer turnOnScreen:isOn];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)selectTemplateSample:(NSInteger)templateID slideID:(NSInteger)slideID
{
    @try {
        [_printer selectTemplate:templateID slideID:slideID];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateImageDataSample:(NSInteger)mapID imageID:(NSInteger)imageID
{
    @try {
        [_printer setTemplateImageData:mapID imageID:imageID];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)selectTemplateTextObjectSample:(NSInteger)mapID
{
    @try {
        [_printer selectTemplateTextObject:mapID];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextAlignmentSample:(NSInteger)alignment
{
    @try {
        [_printer setTemplateTextAlignment:alignment];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextLeftMarginSample:(NSInteger)margin
{
    @try {
        [_printer setTemplateTextLeftMargin:margin];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextLineSpacingSample:(NSInteger)spacing
{
    @try {
        [_printer setTemplateTextLineSpacing:spacing];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextBoldSample:(NSInteger)bold
{
    @try {
        [_printer setTemplateTextBold:bold];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextUnderlineSample:(NSInteger)underline
{
    @try {
        [_printer setTemplateTextUnderline:underline];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextSizeSample:(NSInteger)scale
{
    @try {
        [_printer setTemplateTextSize:scale];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextFontSample:(NSInteger)font
{
    @try {
        [_printer setTemplateTextFont:font];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextRegisteredFontSample:(NSInteger)font
{
    @try {
        [_printer setTemplateTextRegisteredFont:font];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextRightSpacingSample:(NSInteger)spacing
{
    @try {
        [_printer setTemplateTextRightSpacing:spacing];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextColorSample:(NSInteger)color
{
    @try {
        [_printer setTemplateTextColor:color];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateTextDataSample:(NSString *)text
{
    @try {
        [_printer setTemplateTextData:text];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateBarcodeDataSample:(NSInteger)mapID text:(NSString *)text
{
    @try {
        [_printer setTemplateBarcodeData:mapID text:text];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)setTemplateQrCodeDataSample:(NSInteger)mapID text:(NSString *)text
{
    @try {
        [_printer setTemplateQrCodeData:mapID text:text];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerTemplateSample:(NSInteger)templateID label:(NSString *)label fileName:(NSString *)fileName
{
    @try {
        [_printer registerTemplate:templateID label:label fileName:fileName];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterTemplateSample:(NSInteger)templateID
{
    @try {
        [_printer unregisterTemplate:templateID];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerImageDataSample:(NSInteger)imageID label:(NSString *)label fileName:(NSString *)fileName
{
    @try {
        [_printer registerImageData:imageID label:label fileName:fileName];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterImageDataSample:(NSInteger)imageID
{
    @try {
        [_printer unregisterImageData:imageID];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerSlideDataSample:(NSInteger)slideID label:(NSString *)label fileName:(NSString *)fileName
{
    @try {
        [_printer registerSlideData:slideID label:label fileName:fileName];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterSlideDataSample:(NSInteger)slideID
{
    @try {
        [_printer unregisterSlideData:slideID];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerUserDefinedCharacterSample:(NSString *)fileName
{
    @try {
        [_printer registerUserDefinedCharacter:fileName];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterUserDefinedCharacterSample
{
    @try {
        [_printer unregisterUserDefinedCharacter];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)registerOptionFontSample:(NSInteger)startCode endCode:(NSInteger)endCode width:(NSInteger)width height:(NSInteger)height fileName:(NSString *)fileName
{
    @try {
        [_printer registerOptionFont:startCode endCode:endCode width:width height:height fileName:fileName];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)unregisterOptionFontSample
{
    @try {
        [_printer unregisterOptionFont];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)controlMacroRegistrationSample:(NSInteger)macroID control:(NSInteger)control
{
    @try {
        [_printer controlMacroRegistration:macroID control:control];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)getDisplayResponseSample:(NSInteger)responseId
{
    if (responseId == SII_PM_DISPLAY_RESPONSE_REQUEST) {
        return [self response_displayRequest];
    } else if (responseId == SII_PM_DISPLAY_RESPONSE_USER_AREA) {
        return [self response_displayUserarea];
    } else if (responseId == SII_PM_DISPLAY_RESPONSE_TEMPLATE_ID_LIST) {
        return [self response_displayTemplateID];
    } else if (responseId == SII_PM_DISPLAY_RESPONSE_IMAGE_ID_LIST) {
        return [self response_displayImageID];
    } else if (responseId == SII_PM_DISPLAY_RESPONSE_SLIDE_ID_LIST) {
        return [self response_displaySlideID];
    } else {
         _resultMessage = @"responseId invalid\n";
        return NO;
    }
}

+ (BOOL)getDisplayResponseSample:(NSInteger)responseId paramId:(NSInteger)paramId
{
    if (responseId == SII_PM_DISPLAY_RESPONSE_TEMPLATE_LABEL) {
        return [self response_displayTemplateLabel:paramId];
    } else if (responseId == SII_PM_DISPLAY_RESPONSE_IMAGE_LABEL) {
        return [self response_displayImageLabel:paramId];
    } else if (responseId == SII_PM_DISPLAY_RESPONSE_SLIDE_LABEL) {
        return [self response_displaySlideLabel:paramId];
    } else {
         _resultMessage = @"responseId invalid\n";
        return NO;
    }
}

+ (BOOL)response_displayRequest
{
    @try {
        UInt8 param[1] = { 0x41 };
        NSInteger val[1];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_REQUEST param:[NSData dataWithBytes:param length:sizeof(param)] response:val];
        _resultMessage = [NSString stringWithFormat:@"REQUEST:0x%02lX", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displayUserarea
{
    @try {
        NSInteger val[1];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_USER_AREA param:nil response:val];
        _resultMessage = [NSString stringWithFormat:@"USER_AREA:%ld", (long)val[0]];
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displayTemplateID
{
    @try {
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_TEMPLATE_ID_LIST param:nil response:(__bridge void *)(ret)];
        
        NSMutableString *str = [NSMutableString stringWithCapacity:10];
        [str appendString:@"TEMPLATE_ID:"];
        for (int i=0; i<ret.count; i++) {
            NSInteger readID = [[ret objectAtIndex:i] intValue];
            [str appendString:[NSString stringWithFormat:@"%ld, ", (long)readID]];
        }
        _resultMessage = str;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displayImageID
{
    @try {
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_IMAGE_ID_LIST param:nil response:(__bridge void *)(ret)];
        
        NSMutableString *str = [NSMutableString stringWithCapacity:10];
        [str appendString:@"IMAGE_ID:"];
        for (int i=0; i<ret.count; i++) {
            NSInteger readID = [[ret objectAtIndex:i] intValue];
            [str appendString:[NSString stringWithFormat:@"%ld, ", (long)readID]];
        }
        _resultMessage = str;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displaySlideID
{
    @try {
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_SLIDE_ID_LIST param:nil response:(__bridge void *)(ret)];
        
        NSMutableString *str = [NSMutableString stringWithCapacity:10];
        [str appendString:@"SLIDE_ID:"];
        for (int i=0; i<ret.count; i++) {
            NSInteger readID = [[ret objectAtIndex:i] intValue];
            [str appendString:[NSString stringWithFormat:@"%ld, ", (long)readID]];
        }
        _resultMessage = str;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displayTemplateLabel:(NSInteger)templateID
{
    @try {
        UInt8 param[1] = { templateID };
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_TEMPLATE_LABEL param:[NSData dataWithBytes:param length:sizeof(param)] response:(__bridge void *)(ret)];
        NSString *resultText = @"TEMPLATE_LABEL:";
        if (ret.count == 1) {
            resultText = [resultText stringByAppendingString:[NSString stringWithFormat:@"%@", [ret objectAtIndex:0]]];
        } else {
            resultText = [resultText stringByAppendingString:@"Not found"];
        }
        _resultMessage = resultText;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displayImageLabel:(NSInteger)imageID
{
    @try {
        UInt8 param[1] = { imageID };
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_IMAGE_LABEL param:[NSData dataWithBytes:param length:sizeof(param)] response:(__bridge void *)(ret)];
        NSString *resultText = @"IMAGE_LABEL:";
        if (ret.count == 1) {
            resultText = [resultText stringByAppendingString:[NSString stringWithFormat:@"%@", [ret objectAtIndex:0]]];
        } else {
            resultText = [resultText stringByAppendingString:@"Not found"];
        }
        _resultMessage = resultText;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)response_displaySlideLabel:(NSInteger)slideID
{
    @try {
        UInt8 param[1] = { slideID };
        NSMutableArray *ret = [[NSMutableArray alloc] init];
        [_printer getDisplayResponse:SII_PM_DISPLAY_RESPONSE_SLIDE_LABEL param:[NSData dataWithBytes:param length:sizeof(param)] response:(__bridge void *)(ret)];
        NSString *resultText = @"SLIDE_LABEL:";
        if (ret.count == 1) {
            resultText = [resultText stringByAppendingString:[NSString stringWithFormat:@"%@", [ret objectAtIndex:0]]];
        } else {
            resultText = [resultText stringByAppendingString:@"Not found"];
        }
        _resultMessage = resultText;
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)selectSmartLabelFileSample:(NSString *)filePath
{
    @try {
        [_label selectSmartLabelFile:filePath];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)replaceSmartLabelTextDataSample:(NSInteger)mapID text:(NSString *)text
{
    @try {
        [_label replaceSmartLabelTextData:mapID text:text];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)replaceSmartLabelBarcodeDataSample:(NSInteger)mapID text:(NSString *)text
{
    @try {
        [_label replaceSmartLabelBarcodeData:mapID text:text];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)replaceSmartLabelImageDataSample:(NSInteger)mapID image:(UIImage *)image
{
    @try {
        [_label replaceSmartLabelImageData:mapID image:image];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (BOOL)printSmartLabelImageDataSample
{
    @try {
        [_printer printSmartLabelImageData:_label];
        _resultMessage = @"Succeeded";
        return YES;
    }
    @catch (SIIPrinterException *e) {
        _resultMessage = [self getErrorMessage:e.errorCode];
        return NO;
    }
}

+ (NSString *)getErrorMessage:(NSInteger)errorCode
{
    switch (errorCode) {
        case SII_PM_ERROR_ACCESS_DENIED:
            return @"Exception:ACCESS_DENIED";
        case SII_PM_ERROR_SHARING_VIOLATION:
            return @"Exception:SHARING_VIOLATION";
        case SII_PM_ERROR_PORT_NOT_OPENED:
            return @"Exception:PORT_NOT_OPENED";
        case SII_PM_ERROR_DEVICE_NOT_CONNECTED:
            return @"Exception:DEVICE_NOT_CONNECTED";
        case SII_PM_ERROR_OFFLINE:
            return @"Exception:OFFLINE";
        case SII_PM_ERROR_EXTERNAL_DEVICE_NOT_CONNECTED:
            return @"Exception:EXTERNAL_DEVICE_NOT_CONNECTED";
        case SII_PM_ERROR_DEVICE_INITIALIZE_FAILED:
            return @"Exception:DEVICE_INITIALIZE_FAILED";
        case SII_PM_ERROR_DATA_SIZE_ZERO:
            return @"Exception:DATA_SIZE_ZERO";
        case SII_PM_ERROR_OVER_MAX_DATA_SIZE:
            return @"Exception:OVER_MAX_DATA_SIZE";
        case SII_PM_ERROR_DATA_SIZE_INVALID:
            return @"Exception:DATA_SIZE_INVALID";
        case SII_PM_ERROR_ENCODE_FAILED:
            return @"Exception:ENCODE_FAILED";
        case SII_PM_ERROR_TIMEOUT:
            return @"Exception:TIMEOUT";
        case SII_PM_ERROR_FILE_NOT_FOUND:
            return @"Exception:FILE_NOT_FOUND";
        case SII_PM_ERROR_FILE_USED:
            return @"Exception:FILE_USED";
        case SII_PM_ERROR_FILE_INVALID:
            return @"Exception:FILE_INVALID";
        case SII_PM_ERROR_LOW_MEMORY:
            return @"Exception:LOW_MEMORY";
        case SII_PM_ERROR_OVER_MAX_IMAGE:
            return @"Exception:OVER_MAX_IMAGE";
        case SII_PM_ERROR_LOGO_NOT_DEFINED:
            return @"Exception:LOGO_NOT_DEFINED";
        case SII_PM_ERROR_LOW_USER_AREA:
            return @"Exception:LOW_USER_AREA";
        case SII_PM_ERROR_LOW_EXTERNAL_RAM:
            return @"Exception:LOW_EXTERNAL_RAM";
        case SII_PM_ERROR_NOT_REGISTERD:
            return @"Exception:NOT_REGISTERD";
        case SII_PM_ERROR_NOT_UNREGISTERD:
            return @"Exception:NOT_UNREGISTERD";
        case SII_PM_ERROR_INVALID_NO:
            return @"Exception:INVALID_NO";
        case SII_PM_ERROR_OVER_STYLE_NUM:
            return @"Exception:OVER_STYLE_NUM";
        case SII_PM_ERROR_INVALID_DATA:
            return @"Exception:INVALID_DATA";
        case SII_PM_ERROR_PAGE_MODE_SPECIFIED:
            return @"Exception:PAGE_MODE_SPECIFIED";
        case SII_PM_ERROR_PAGE_MODE_NOT_SPECIFIED:
            return @"Exception:PAGE_MODE_NOT_SPECIFIED";
        case SII_PM_ERROR_LABEL_FILE_NOT_SELECTED:
            return @"Exception:LABEL_FILE_NOT_SELECTED";
        case SII_PM_ERROR_GET_LABEL_IMAGE:
            return @"Exception:GET_LABEL_IMAGE";
        case SII_PM_ERROR_INVALID_PARAM:
            return @"Exception:INVALID_PARAM";
        default:
            return @"Exception:Unknown error";
    }
}

+ (NSString *)getResultMessage
{
    return _resultMessage;
}

@end
