//
//  ViewController.m
//  SiiLibSample
//

#import "ViewController.h"
#import "UserDefaults.h"
#import "Sample.h"
#import <ExternalAccessory/ExternalAccessory.h>

#define DOCUMENTS_PATH [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0]

static NSString *const SII_EXTERNAL_ACCESSORY_PROTOCOL = @"com.sii-ps.siieap";
static const int SEGMENT_TCP_IP = 0;
static const int SEGMENT_BLUETOOTH = 1;
static const int SEGMENT_USB = 2;

@interface ViewController () {
    UIView *_loadingViewBackGraund;
    UIView *_loadingViewFrame;
    UIActivityIndicatorView *_loadingIndicator;
    UIButton *_cancelButton;
    dispatch_queue_t _gcd_buttonTappedQueue;
}

@end

@implementation ViewController

+ (void) initialize
{
    [super initialize];
    //
    NSMutableDictionary *appDefaults = [[NSMutableDictionary alloc] init];
    [appDefaults setObject:TEXT_FIELD_TYPE_BLUETOOTH forKey:KEY_TYPE_INTERFACE];
    [appDefaults setObject:TEXT_FIELD_DEFAULT_MODEL forKey:KEY_IP_PRINTER_MODEL];
    [appDefaults setObject:TEXT_FIELD_DEFAULT_MODEL forKey:KEY_BLUETOOTH_PRINTER_MODEL];
    [appDefaults setObject:TEXT_FIELD_DEFAULT_MODEL forKey:KEY_USB_PRINTER_MODEL];
    [appDefaults setObject:TEXT_FIELD_DEFAULT_ADDRESS forKey:KEY_IP_ADDRESS];
    [appDefaults setObject:TEXT_FIELD_DEFAULT_ADDRESS forKey:KEY_BLUETOOTH_ADDRESS];
    [appDefaults setObject:TEXT_FIELD_DEFAULT_ADDRESS forKey:KEY_USB_ADDRESS];
    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
    [userDefaults registerDefaults:appDefaults];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.

    [Sample InitialSetting:self];
    [self configureUIButtons];
    [self configureLoadingView];
    [self configureUITextField];
    _gcd_buttonTappedQueue = dispatch_queue_create("com.sii-ps.buttonTapped", DISPATCH_QUEUE_SERIAL);
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    //
    NSUserDefaults *myDefaults = [NSUserDefaults standardUserDefaults];
    if ([[myDefaults stringForKey:KEY_TYPE_INTERFACE] isEqualToString:TEXT_FIELD_TYPE_TCP])
    {
        _printerTypeSeg.selectedSegmentIndex = SEGMENT_TCP_IP;
        _printerModel.text = [myDefaults stringForKey:KEY_IP_PRINTER_MODEL];
        _addressTxt.text = [myDefaults stringForKey:KEY_IP_ADDRESS];
    } else if ([[myDefaults stringForKey:KEY_TYPE_INTERFACE] isEqualToString:TEXT_FIELD_TYPE_BLUETOOTH]) {
        _printerTypeSeg.selectedSegmentIndex = SEGMENT_BLUETOOTH;
        _printerModel.text = [myDefaults stringForKey:KEY_BLUETOOTH_PRINTER_MODEL];
        _addressTxt.text = [myDefaults stringForKey:KEY_BLUETOOTH_ADDRESS];
    } else if ([[myDefaults stringForKey:KEY_TYPE_INTERFACE] isEqualToString:TEXT_FIELD_TYPE_USB]) {
        _printerTypeSeg.selectedSegmentIndex = SEGMENT_USB;
        _printerModel.text = [myDefaults stringForKey:KEY_USB_PRINTER_MODEL];
        _addressTxt.text = [myDefaults stringForKey:KEY_USB_ADDRESS];
    }
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
    //
    [_scrollView setContentSize:CGSizeMake(288, 3612)];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)viewWillTransitionToSize:(CGSize)size withTransitionCoordinator:(id<UIViewControllerTransitionCoordinator>)coordinator
{
    [super viewWillTransitionToSize:size withTransitionCoordinator:coordinator];
    //
    [coordinator animateAlongsideTransition:^(id<UIViewControllerTransitionCoordinatorContext> context) {
        self->_loadingViewBackGraund.frame = self.view.bounds;
        self->_loadingViewFrame.layer.position = CGPointMake(CGRectGetMidX(self.view.bounds), CGRectGetMidY(self.view.bounds));
        self->_cancelButton.layer.position = CGPointMake(CGRectGetMidX(self->_loadingViewFrame.bounds), 95.0f);
    } completion:nil];
}

#pragma mark - Button Action
- (IBAction)onPrinterTypeSegClicked:(id)sender
{
    if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_TCP_IP) {
        [self saveDefault:TEXT_FIELD_TYPE_TCP key:KEY_TYPE_INTERFACE];
        _addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_IP_ADDRESS];
        _printerModel.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_IP_PRINTER_MODEL];
    } else if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_BLUETOOTH){
        [self saveDefault:TEXT_FIELD_TYPE_BLUETOOTH key:KEY_TYPE_INTERFACE];
        _addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_BLUETOOTH_ADDRESS];
        _printerModel.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_BLUETOOTH_PRINTER_MODEL];
    } else if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_USB) {
        [self saveDefault:TEXT_FIELD_TYPE_USB key:KEY_TYPE_INTERFACE];
        _addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_USB_ADDRESS];
        _printerModel.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_USB_PRINTER_MODEL];
    }
}

- (IBAction)onSelectPrinterModelButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"" message:@"Select printer model" preferredStyle:UIAlertControllerStyleAlert];
    NSArray *modelList = @[@"DPU-S245", @"DPU-S445", @"MP-B20", @"MP-B30", @"MP-B30L", @"RP-D10", @"RP-E10", @"RP-F10", @"SLP720RT"];
    for (int i=0; i<modelList.count; i++) {
        NSString *modelName = [modelList objectAtIndex:i];
        [alertController addAction:[UIAlertAction actionWithTitle:modelName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            self->_printerModel.text = modelName;
            if (self->_printerTypeSeg.selectedSegmentIndex == SEGMENT_TCP_IP) {
                if ([modelName isEqualToString:@"DPU-S245"] || [modelName isEqualToString:@"DPU-S445"] || [modelName isEqualToString:@"MP-B20"]) {
                    self->_printerTypeSeg.selectedSegmentIndex = SEGMENT_BLUETOOTH;
                    [self saveDefault:TEXT_FIELD_TYPE_BLUETOOTH key:KEY_TYPE_INTERFACE];
                    [self saveDefault:self->_printerModel.text key:KEY_BLUETOOTH_PRINTER_MODEL];
                    self->_addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_BLUETOOTH_ADDRESS];
                } else {
                    [self saveDefault:self->_printerModel.text key:KEY_IP_PRINTER_MODEL];
                }
            } else if (self->_printerTypeSeg.selectedSegmentIndex == SEGMENT_BLUETOOTH) {
                if ([modelName isEqualToString:@"SLP720RT"]) {
                    self->_printerTypeSeg.selectedSegmentIndex = SEGMENT_TCP_IP;
                    [self saveDefault:TEXT_FIELD_TYPE_TCP key:KEY_TYPE_INTERFACE];
                    [self saveDefault:self->_printerModel.text key:KEY_IP_PRINTER_MODEL];
                    self->_addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_IP_ADDRESS];
                }else{
                    [self saveDefault:self->_printerModel.text key:KEY_BLUETOOTH_PRINTER_MODEL];
                }
            } else if (self->_printerTypeSeg.selectedSegmentIndex == SEGMENT_USB) {
                if ([modelName isEqualToString:@"RP-F10"]) {
                    [self saveDefault:self->_printerModel.text key:KEY_USB_PRINTER_MODEL];
                }else if ([modelName isEqualToString:@"SLP720RT"]) {
                    self->_printerTypeSeg.selectedSegmentIndex = SEGMENT_TCP_IP;
                    [self saveDefault:TEXT_FIELD_TYPE_TCP key:KEY_TYPE_INTERFACE];
                    [self saveDefault:self->_printerModel.text key:KEY_IP_PRINTER_MODEL];
                    self->_addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_IP_ADDRESS];
                } else {
                    self->_printerTypeSeg.selectedSegmentIndex = SEGMENT_BLUETOOTH;
                    [self saveDefault:TEXT_FIELD_TYPE_BLUETOOTH key:KEY_TYPE_INTERFACE];
                    [self saveDefault:self->_printerModel.text key:KEY_BLUETOOTH_PRINTER_MODEL];
                    self->_addressTxt.text = [[NSUserDefaults standardUserDefaults] stringForKey:KEY_BLUETOOTH_ADDRESS];
                }
            }
        }]];
    }
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSerchButtonClicked:(id)sender
{
    if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_TCP_IP) {
        dispatch_async(_gcd_buttonTappedQueue, ^{
            [self startLoadingView:YES];
            [Sample startLanDiscoveryPrinterSample:1 timeout:10000];
            while (![Sample getPrinterDiscoveryCompletion]) {
                [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:[NSDate distantFuture]];
            }
            [self stopLoadingView];
            NSArray *printerList = [Sample getFoundPrinterSample];
            dispatch_async(dispatch_get_main_queue(), ^{
                if (printerList != nil && printerList.count > 0) {
                    UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"Select printer address" preferredStyle:UIAlertControllerStyleAlert];
                    NSArray *printerList = [Sample getFoundPrinterSample];
                    for (int i=0; i<printerList.count; i++) {
                        SIIPrinterInfo *obj = [printerList objectAtIndex:i];
                        NSString *title = [NSString stringWithFormat:@"%@(%@)", obj.name, obj.ip];
                        [alertController addAction:[UIAlertAction actionWithTitle:title style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                            self->_addressTxt.text = [NSString stringWithFormat:@"%@",obj.ip];
                            [self saveDefault:self->_addressTxt.text key:KEY_IP_ADDRESS];
                        }]];
                    }
                    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
                    }]];
                    [self presentViewController:alertController animated:YES completion:nil];
                } else {
                    UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"Printer is not found" preferredStyle:UIAlertControllerStyleAlert];
                    [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    }]];
                    [self presentViewController:alertController animated:YES completion:nil];
                }
            });
        });
    } else if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_BLUETOOTH || _printerTypeSeg.selectedSegmentIndex == SEGMENT_USB) {
        NSMutableArray *printerList = [[NSMutableArray alloc] init];
        NSArray *accessories = [[EAAccessoryManager sharedAccessoryManager] connectedAccessories];
        if (accessories != nil && accessories.count > 0) {
            for (EAAccessory *obj in accessories) {
                if ([[obj protocolStrings] containsObject:SII_EXTERNAL_ACCESSORY_PROTOCOL]) {
                    NSString *macAddress = [obj valueForKey:@"macAddress"];
                    if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_BLUETOOTH && macAddress != nil) {
                        [printerList addObject:obj.name];
                    } else if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_USB && macAddress == nil) {
                        [printerList addObject:obj.name];
                    }
                }
            }
        }
        if (printerList.count > 0) {
            UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"" message:@"Select printer Device" preferredStyle:UIAlertControllerStyleAlert];
            for (int i = 0; i < printerList.count; i++) {
                NSString *printerName = [printerList objectAtIndex:i];
                [alertController addAction:[UIAlertAction actionWithTitle:printerName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    self->_addressTxt.text = printerName;
                    if (self->_printerTypeSeg.selectedSegmentIndex == SEGMENT_BLUETOOTH) {
                        [self saveDefault:self->_addressTxt.text key:KEY_BLUETOOTH_ADDRESS];
                    } else if (self->_printerTypeSeg.selectedSegmentIndex == SEGMENT_USB) {
                        [self saveDefault:self->_addressTxt.text key:KEY_USB_ADDRESS];
                    }
                }]];
            }
            [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
            }]];
            [self presentViewController:alertController animated:YES completion:nil];
        } else {
            UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"Printer is not found" preferredStyle:UIAlertControllerStyleAlert];
            [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
            }]];
            [self presentViewController:alertController animated:YES completion:nil];
        }
    }
}

- (IBAction)onConnectButtonClicked:(id)sender
{
    NSInteger model = -1;
    if ([_printerModel.text isEqualToString:@"DPU-S245"]) {
        model = SII_PM_PRINTER_MODEL_DPU_S245;
    } else if ([_printerModel.text isEqualToString:@"DPU-S445"]) {
        model = SII_PM_PRINTER_MODEL_DPU_S445;
    } else if ([_printerModel.text isEqualToString:@"RP-E10"]) {
        model = SII_PM_PRINTER_MODEL_RP_E10;
    } else if ([_printerModel.text isEqualToString:@"RP-D10"]) {
        model = SII_PM_PRINTER_MODEL_RP_D10;
    } else if ([_printerModel.text isEqualToString:@"MP-B20"]) {
        model = SII_PM_PRINTER_MODEL_MP_B20;
    } else if ([_printerModel.text isEqualToString:@"MP-B30"]) {
        model = SII_PM_PRINTER_MODEL_MP_B30;
    } else if ([_printerModel.text isEqualToString:@"RP-F10"]) {
        model = SII_PM_PRINTER_MODEL_RP_F10;
    } else if ([_printerModel.text isEqualToString:@"MP-B30L"]) {
        model = SII_PM_PRINTER_MODEL_MP_B30L;
    } else if ([_printerModel.text isEqualToString:@"SLP720RT"]) {
        model = SII_PM_PRINTER_MODEL_SLP720RT;
    }
    NSInteger type = -1;
    if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_TCP_IP) {
        type = SII_PM_PRINTER_PORT_TYPE_TCP;
    } else if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_BLUETOOTH) {
        type = SII_PM_PRINTER_PORT_TYPE_BLUETOOTH;
    } else if (_printerTypeSeg.selectedSegmentIndex == SEGMENT_USB) {
        type = SII_PM_PRINTER_PORT_TYPE_USB;
    }
    NSString *address = _addressTxt.text;
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample connectSample:model address:address type:type];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onDisconnectButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample disconnectSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];

        dispatch_async(dispatch_get_main_queue(), ^{
            self->_lastStatus.text = @"";
            self->_barcodeData.text = @"";
            self->_barcodeStatus.text = @"";
        });
    });
}

- (IBAction)onPrintPageModeSampleButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printPageModeSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onSendTextButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"sendText" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"text input";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = [alertController.textFields.firstObject.text stringByAppendingString:@"\n"];
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample sendTextSample:text];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSendTextExButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"sendTextEx" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"text input";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = [alertController.textFields.firstObject.text stringByAppendingString:@"\n"];
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample sendTextExSample:text];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onPrintBarcodeButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printBarcodeSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintPDF417ButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printPDF417Sample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintQRcodeButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printQRcodeSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintDataMatrixButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printDataMatrixSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintMaxiCodeButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printMaxiCodeSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintGS1DataBarStackedButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printGS1DataBarStackedSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintGS1DataBarStackedOmnidirectionalButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printGS1DataBarStackedOmnidirectionalSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintGS1DataBarExpandedStackedButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printGS1DataBarExpandedStackedSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onPrintAztecCodeButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printAztecCodeSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onCutPaperButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"cutPaper" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Feed & Full cut" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample cutPaperSample:SII_PM_CUT_FULL];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Feed & Partial cut" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample cutPaperSample:SII_PM_CUT_PARTIAL];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Full cut" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample cutPaperSample:SII_PM_CUT_FULL_NO_FEED];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Partial cut" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample cutPaperSample:SII_PM_CUT_PARTIAL_NO_FEED];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onFeedPositionButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample feedPositionSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onOpenDrawerButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample openDrawerSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onBuzzerButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample buzzerSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onExternalBuzzerButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample externalBuzzerSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onSendBinaryButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"sendBinary" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"hex value input";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields.firstObject.text;
        NSData *data =  [self covertHexStringToBinary:text];
        if (data == nil) {
            [self showResult:@"data is not hex value"];
        } else {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample sendBinarySample:data];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSendDataFileButtonClicked:(id)sender
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    if (fileList.count > 0) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"sendDataFile" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath = [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                dispatch_async(self->_gcd_buttonTappedQueue, ^{
                    [self startLoadingView:NO];
                    [Sample sendDataFileSample:filePath];
                    [self stopLoadingView];
                    [self showResult:[Sample getResultMessage]];
                });
            }]];
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onGetStatusButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample getStatusSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onAbortButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample abortSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onRegisterLogoButtonClicked:(id)sender
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"bmp"] || [fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"registerLogo" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"bmp"] || [fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
                [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    dispatch_async(self->_gcd_buttonTappedQueue, ^{
                        [self startLoadingView:NO];
                        [Sample registerLogoSample:filePath];
                        [self stopLoadingView];
                        [self showResult:[Sample getResultMessage]];
                    });
                }]];
            }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onPrintLogoButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printLogoSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onUnregisterLogoButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample unregisterLogoSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onRegisterStyleSheetButtonClicked:(id)sender
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"css"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"registerStyleSheet" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"css"]) {
                [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    dispatch_async(self->_gcd_buttonTappedQueue, ^{
                        [self startLoadingView:NO];
                        [Sample registerStyleSheetSample:filePath];
                        [self stopLoadingView];
                        [self showResult:[Sample getResultMessage]];
                    });
                }]];
            }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onUnregisterStyleSheetButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample unregisterStyleSheetSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onResetPrinterButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample resetPrinterSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onGetPrinterResponseButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"getPrinterResponse" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"REQUEST" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getPrinterResponseSample:SII_PM_PRINTER_RESPONSE_REQUEST];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"USER_AREA" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getPrinterResponseSample:SII_PM_PRINTER_RESPONSE_USER_AREA];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"ARRANGE_USER_AREA" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getPrinterResponseSample:SII_PM_PRINTER_RESPONSE_ARRANGE_USER_AREA];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"NV_GRAPHICS" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getPrinterResponseSample:SII_PM_PRINTER_RESPONSE_NV_GRAPHICS];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"KEY_CODE" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getPrinterResponseSample:SII_PM_PRINTER_RESPONSE_KEY_CODE];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"BATTERY_STATUS" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getPrinterResponseSample:SII_PM_PRINTER_RESPONSE_BATTERY_STATUS];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onStartDiscoveryPrinterButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"startDiscovery" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"TCP/IP" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample startLanDiscoveryPrinterSample:1 timeout:10000];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Bluetooth" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample startBluetoothDiscoveryPrinterSample];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onCancelDiscoveryPrinterButtonClicked:(id)sender
{
    [Sample cancelDiscoveryPrinterSample];
    [self showResult:[Sample getResultMessage]];
}

- (IBAction)onGetFoundPrinterButtonClicked:(id)sender
{
    NSArray *printerList =[Sample getFoundPrinterSample];
    NSString *resultText = @"";
    if (printerList != nil && printerList.count > 0) {
        NSMutableString *str = [NSMutableString stringWithCapacity:10];
        [str appendString:@"List of FoundPrinter\n"];
        for (int i=0; i<printerList.count; i++) {
            SIIPrinterInfo *obj = [printerList objectAtIndex:i];
            [str appendString:[NSString stringWithFormat:@"%@(%@)", obj.name, obj.ip]];
            if (i != printerList.count-1) {
                [str appendString:@"\n"];
            }
        }
        resultText = str;
    } else {
        resultText = @"TCP/IP Printer is not found";
    }
    [self showResult:resultText];
}

- (IBAction)onControlTransactionButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"controlTransaction" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"START" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample controlTransactionSample:SII_PM_TRANSACTION_START];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"PRINT" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample controlTransactionSample:SII_PM_TRANSACTION_PRINT];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"CLEAR" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample controlTransactionSample:SII_PM_TRANSACTION_CLEAR];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onGetVersionButtonOnClicked:(id)sender
{
    [Sample getVersionSample];
    [self showResult:[Sample getResultMessage]];
}

- (IBAction)onSendTimeoutButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"sendTimeout" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"get sendTimeout" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSInteger timeout = [Sample get_sendTimeoutSample];
        [self showResult:[NSString stringWithFormat:@"sendTimeout:%ldmsec", (long)timeout]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"set sendTimeout" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set sendTimeout" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            textField.placeholder = @"timeout value input";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields.firstObject.text;
            BOOL convertInt = YES;
            for (NSInteger i=0; i<text.length; i++) {
                unichar c = [text characterAtIndex:i];
                if (c < 48 || c > 57) {
                    convertInt = NO;
                }
            }
            if (convertInt) {
                [Sample set_sendTimeoutSample:[text integerValue]];
                [self showResult:[Sample getResultMessage]];
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onReceiveTimeoutButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"receiveTimeout" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"get receiveTimeout" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSInteger timeout = [Sample get_receiveTimeoutSample];
        [self showResult:[NSString stringWithFormat:@"receiveTimeout:%ldmsec", (long)timeout]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"set receiveTimeout" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set receiveTimeout" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            textField.placeholder = @"timeout value input";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields.firstObject.text;
            BOOL convertInt = YES;
            for (NSInteger i=0; i<text.length; i++) {
                unichar c = [text characterAtIndex:i];
                if (c < 48 || c > 57) {
                    convertInt = NO;
                }
            }
            if (convertInt) {
                [Sample set_receiveTimeoutSample:[text integerValue]];
                [self showResult:[Sample getResultMessage]];
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onInternationalCharacterButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"internationalCharacter" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"get internationalCharacter" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample get_internationalCharacterSample];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"set internationalCharacter" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set internationalCharacter" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"USA" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_USA];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"FRANCE" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_FRANCE];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"GERMANY" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_GERMANY];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"ENGLAND" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_ENGLAND];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"DENMARK_1" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_DENMARK_1];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"SWEDEN" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_SWEDEN];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"ITALY" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_ITALY];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"SPAIN" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_SPAIN];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"JAPAN" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_JAPAN];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"NORWAY" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_NORWAY];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"DENMARK_2" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_DENMARK_2];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"SPAIN_2" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_SPAIN_2];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"LATIN_AMERICA" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_LATIN_AMERICA];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"ARABIA" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_internationalCharacterSample:SII_PM_COUNTRY_ARABIA];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onCodePageButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"codePage" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"get codePage" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample get_codePageSample];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"set codePage" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set codePage" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 437" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_437];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage Katakana" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_KATAKANA];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 850" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_850];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 860" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_860];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 863" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_863];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 865" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_865];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 857" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_857];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 737" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_737];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 1252" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_1252];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 866" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_866];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 852" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_852];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 858" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_858];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 855" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_855];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 864" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_864];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 1250" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_1250];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 1251" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_1251];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 1253" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_1253];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"codePage 1254" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            [Sample set_codePageSample:SII_PM_CODE_PAGE_1254];
            [self showResult:[Sample getResultMessage]];
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onPrinterModelButtonClicked:(id)sender
{
    [Sample get_printerModelSample];
    [self showResult:[Sample getResultMessage]];
}

- (IBAction)onPortTypeButtonClicked:(id)sender
{
    [Sample get_portTypeSample];
    [self showResult:[Sample getResultMessage]];
}

- (IBAction)onIsConnectButtonClicked:(id)sender
{
    [Sample get_isConnectSample];
    [self showResult:[Sample getResultMessage]];
}

- (IBAction)onSocketKeepingTimeButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"socketKeepingTime" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"get socketKeepingTime" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSInteger socketKeepingTime = [Sample get_socketKeepingTimeSample];
        [self showResult:[NSString stringWithFormat:@"socketKeepingTime:%ldmsec", (long)socketKeepingTime]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"set socketKeepingTime" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set socketKeepingTime" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            textField.placeholder = @"timeout value input";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields.firstObject.text;
            BOOL convertInt = YES;
            for (NSInteger i=0; i<text.length; i++) {
                unichar c = [text characterAtIndex:i];
                if (c < 48 || c > 57) {
                    convertInt = NO;
                }
            }
            if (convertInt) {
                [Sample set_socketKeepingTimeSample:[text integerValue]];
                [self showResult:[Sample getResultMessage]];
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

#pragma mark Display API
- (IBAction)onDefragmentButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample defragmentSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onShowTemplateButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set time" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Time(ms)";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 255000";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample showTemplateSample:value];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onShowSlideButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set slide id and time" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Slide ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 91";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Time(ms)";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 255000";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        NSInteger value2 = [self convertTextToInt:text2];
        if (value >= 0 && value2 >= 0) {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample showSlideSample:value time_ms:value2];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onEnterStandByButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample enterStandbyModeSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onExecuteMacroButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set macro id and time" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Macro ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 127";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Repeat count";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        NSInteger value2 = [self convertTextToInt:text2];
        if (value >= 0 && value2 >= 0) {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample executeMacroSample:value repeatCount:value2];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onTurnOnScreenButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select isON" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"ON" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample turnOnScreenSample:YES];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OFF" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample turnOnScreenSample:NO];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSelectTemplateButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set template id and slide id" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Template ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 127";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Slide ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 91";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        NSInteger value2 = [self convertTextToInt:text2];
        if (value >= 0 && value2 >= -1) {
            [Sample selectTemplateSample:value slideID:value2];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateImageDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set map id and image id" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Map ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 63";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Image ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 63";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        NSInteger value2 = [self convertTextToInt:text2];
        if (value >= 0 && value2 >= 0) {
            [Sample setTemplateImageDataSample:value imageID:value2];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSelectTemplateTextObjectButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select map id" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Map ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 63";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            [Sample selectTemplateTextObjectSample:value];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextAlignmentButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select alignment" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"LEFT" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextAlignmentSample:SII_PM_ALIGNMENT_LEFT];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"CENTER" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextAlignmentSample:SII_PM_ALIGNMENT_CENTER];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"RIGHT" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextAlignmentSample:SII_PM_ALIGNMENT_RIGHT];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextLeftMarginButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set left margine" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Margine";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 479";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            [Sample setTemplateTextLeftMarginSample:value];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextLineSpacingButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set line spacing" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Spacing";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            [Sample setTemplateTextLineSpacingSample:value];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextBoldButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select bold" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"BOLD" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextBoldSample:SII_PM_BOLD];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"BOLD CANCEL" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextBoldSample:SII_PM_BOLD_CANCEL];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextUnderlineButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select underline" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"UNDERLINE" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextUnderlineSample:SII_PM_UNDERLINE_1];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"UNDERLINE CANCEL" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextUnderlineSample:SII_PM_UNDERLINE_CANCEL];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextSizeButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select scale\nwidth x height" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"1 x 1" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_1_HORIZONTAL_1];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"2 x 1" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_1_HORIZONTAL_2];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"3 x 1" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_1_HORIZONTAL_3];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"4 x 1" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_1_HORIZONTAL_4];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"1 x 2" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_2_HORIZONTAL_1];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"2 x 2" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_2_HORIZONTAL_2];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"3 x 2" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_2_HORIZONTAL_3];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"4 x 2" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_2_HORIZONTAL_4];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"1 x 3" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_3_HORIZONTAL_1];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"2 x 3" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_3_HORIZONTAL_2];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"3 x 3" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_3_HORIZONTAL_3];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"4 x 3" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_3_HORIZONTAL_4];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"1 x 4" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_4_HORIZONTAL_1];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"2 x 4" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_4_HORIZONTAL_2];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"3 x 4" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_4_HORIZONTAL_3];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"4 x 4" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextSizeSample:SII_PM_VARTICAL_4_HORIZONTAL_4];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextFontButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select font" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"FONT_A" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextFontSample:SII_PM_FONT_A];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"FONT_B" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextFontSample:SII_PM_FONT_B];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextRegisteredFontButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select font" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"STANDARD" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextRegisteredFontSample:SII_PM_FONT_STANDARD];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OPTION" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextRegisteredFontSample:SII_PM_FONT_OPTION];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextRightSpacingButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set right spacing" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Spacing";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            [Sample setTemplateTextRightSpacingSample:value];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextColorButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select color" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"black" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0x000000];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"blue" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0x0000ff];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"green" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0x00ff00];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"cyan" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0x00ffff];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"red" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0xff0000];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"magenta" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0xff00ff];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"yellow" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0xffff00];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"white" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample setTemplateTextColorSample:0xffffff];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateTextDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set text" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"text";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields.firstObject.text;
        [Sample setTemplateTextDataSample:text];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateBarcodeDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set map id and barcode data"  message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Map ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 7";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Barcode data";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"text";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        if (value >= 0) {
            [Sample setTemplateBarcodeDataSample:value text:text2];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSetTemplateQrCodeDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set map id and QRcode data"  message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Map ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 7";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"QRcode data";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"text";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        if (value >= 0) {
            [Sample setTemplateQrCodeDataSample:value text:text2];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onRegisterTemplateButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set template id and label" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Template ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 127";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Label";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"text";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *label = alertController.textFields[1].text;
        if (value >= 0) {
            [self showRegisterTemplateSelectFileView:value label:label];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)showRegisterTemplateSelectFileView:(NSInteger)value label:(NSString *)label
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"xml"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select file" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
                if ([fileExtention isEqualToString:@"xml"]) {
                    [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                        dispatch_async(self->_gcd_buttonTappedQueue, ^{
                            [self startLoadingView:NO];
                            [Sample registerTemplateSample:value label:label fileName:filePath];
                            [self stopLoadingView];
                            [self showResult:[Sample getResultMessage]];
                        });
                    }]];
                }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onUnregisterTemplateButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set template id" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Template ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 127";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample unregisterTemplateSample:value];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onRegisterImageDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set image id and label" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Image ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 63";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Label";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"text";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *label = alertController.textFields[1].text;
        if (value >= 0) {
            [self showRegisterImageDataSelectFileView:value label:label];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)showRegisterImageDataSelectFileView:(NSInteger)value label:(NSString *)label
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select file" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
                    [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                        dispatch_async(self->_gcd_buttonTappedQueue, ^{
                            [self startLoadingView:NO];
                            NSInteger timeout = [Sample get_sendTimeoutSample];
                            if (timeout < 60000) {
                                [Sample set_sendTimeoutSample:60000];
                            }
                            [Sample registerImageDataSample:value label:label fileName:filePath];
                            [Sample set_sendTimeoutSample:timeout];
                            [self stopLoadingView];
                            [self showResult:[Sample getResultMessage]];
                        });
                    }]];
                }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onUnregisterImageDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set image id" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Image ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 63";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample unregisterImageDataSample:value];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onRegisterSlideDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set slide id and label" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Slide ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 91";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Label";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"text";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *label = alertController.textFields[1].text;
        if (value >= 0) {
            [self showRegisterSlideDataSelectFileView:value label:label];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)showRegisterSlideDataSelectFileView:(NSInteger)value label:(NSString *)label
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select file" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
                    [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                        dispatch_async(self->_gcd_buttonTappedQueue, ^{
                            [self startLoadingView:NO];
                            NSInteger timeout = [Sample get_sendTimeoutSample];
                            if (timeout < 60000) {
                                [Sample set_sendTimeoutSample:60000];
                            }
                            [Sample registerSlideDataSample:value label:label fileName:filePath];
                            [Sample set_sendTimeoutSample:timeout];
                            [self stopLoadingView];
                            [self showResult:[Sample getResultMessage]];
                        });
                    }]];
                }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onUnregisterSlideDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set slide id" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Slide ID";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"0 to 91";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            dispatch_async(self->_gcd_buttonTappedQueue, ^{
                [self startLoadingView:NO];
                [Sample unregisterSlideDataSample:value];
                [self stopLoadingView];
                [self showResult:[Sample getResultMessage]];
            });
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onRegisterUserDefinedCharacterButtonClicked:(id)sender
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"bin"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select file" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"bin"]) {
                [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    dispatch_async(self->_gcd_buttonTappedQueue, ^{
                        [self startLoadingView:NO];
                        [Sample registerUserDefinedCharacterSample:filePath];
                        [self stopLoadingView];
                        [self showResult:[Sample getResultMessage]];
                    });
                }]];
            }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onUnregisterUserDefinedCharacterButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample unregisterUserDefinedCharacterSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onRegisterOptionFontButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set start and end and width and height" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Start Code";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"32 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"End Code";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"32 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Width";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"1 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
        label.text = @"Height";
        label.font = [UIFont systemFontOfSize:12];
        label.textColor = [UIColor darkGrayColor];
        textField.leftView = label;
        textField.leftViewMode = UITextFieldViewModeAlways;
        textField.placeholder = @"1 to 255";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger startCode = [self convertTextToInt:text];
        text = alertController.textFields[1].text;
        NSInteger endCode = [self convertTextToInt:text];
        text = alertController.textFields[2].text;
        NSInteger width = [self convertTextToInt:text];
        text = alertController.textFields[3].text;
        NSInteger height = [self convertTextToInt:text];
        if (startCode >= 0 && endCode >= 0 && width >= 0 && height >= 0) {
            [self showRegisterOptionSelectFileView:startCode endCode:endCode width:width height:height];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)showRegisterOptionSelectFileView:(NSInteger)startCode endCode:(NSInteger)endCode width:(NSInteger)width height:(NSInteger)height
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray *fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i<fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"bin"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select file" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i<fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"bin"]) {
                [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    dispatch_async(dispatch_get_main_queue(), ^{
                        [self startLoadingView:NO];
                        [Sample registerOptionFontSample:startCode endCode:endCode width:width height:height fileName:filePath];
                        [self stopLoadingView];
                        [self showResult:[Sample getResultMessage]];
                    });
                }]];
            }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onUnregisterOptionFontButtonClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample unregisterOptionFontSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onControlMacroRegistrationButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select control" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Start" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample controlMacroRegistrationSample:-1 control:SII_PM_MACRO_REGISTRATION_START];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Regist" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set macro ID" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
            label.text = @"Macro ID";
            label.font = [UIFont systemFontOfSize:12];
            label.textColor = [UIColor darkGrayColor];
            textField.leftView = label;
            textField.leftViewMode = UITextFieldViewModeAlways;
            textField.placeholder = @"0 to 127";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields[0].text;
            NSInteger value = [self convertTextToInt:text];
            if (value >= -1) {
                dispatch_async(self->_gcd_buttonTappedQueue, ^{
                    [self startLoadingView:NO];
                    [Sample controlMacroRegistrationSample:value control:SII_PM_MACRO_REGISTRATION_REGIST];
                    [self stopLoadingView];
                    [self showResult:[Sample getResultMessage]];
                });
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Clear" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        [Sample controlMacroRegistrationSample:-1 control:SII_PM_MACRO_REGISTRATION_CLEAR];
        [self showResult:[Sample getResultMessage]];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onGetDisplayResponseButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"getDisplayResponse" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addAction:[UIAlertAction actionWithTitle:@"REQUEST" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_REQUEST];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"USER_AREA" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_USER_AREA];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"TEMPLATE_ID_LIST" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_TEMPLATE_ID_LIST];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"IMAGE_ID_LIST" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_IMAGE_ID_LIST];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"SLIDE_ID_LIST" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        dispatch_async(self->_gcd_buttonTappedQueue, ^{
            [self startLoadingView:NO];
            [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_SLIDE_ID_LIST];
            [self stopLoadingView];
            [self showResult:[Sample getResultMessage]];
        });
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"TEMPLATE_LABEL" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set template ID" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
            label.text = @"Template ID";
            label.font = [UIFont systemFontOfSize:12];
            label.textColor = [UIColor darkGrayColor];
            textField.leftView = label;
            textField.leftViewMode = UITextFieldViewModeAlways;
            textField.placeholder = @"0 to 127";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields[0].text;
            NSInteger value = [self convertTextToInt:text];
            if (value >= 0) {
                dispatch_async(self->_gcd_buttonTappedQueue, ^{
                    [self startLoadingView:NO];
                    [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_TEMPLATE_LABEL paramId:value];
                    [self stopLoadingView];
                    [self showResult:[Sample getResultMessage]];
                });
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"IMAGE_LABEL" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set image ID" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
            label.text = @"Image ID";
            label.font = [UIFont systemFontOfSize:12];
            label.textColor = [UIColor darkGrayColor];
            textField.leftView = label;
            textField.leftViewMode = UITextFieldViewModeAlways;
            textField.placeholder = @"0 to 63";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields[0].text;
            NSInteger value = [self convertTextToInt:text];
            if (value >= 0) {
                dispatch_async(self->_gcd_buttonTappedQueue, ^{
                    [self startLoadingView:NO];
                    [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_IMAGE_LABEL paramId:value];
                    [self stopLoadingView];
                    [self showResult:[Sample getResultMessage]];
                });
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"SLIDE_LABEL" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        UIAlertController *alertControllerSub = [UIAlertController alertControllerWithTitle:@"set slide ID" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alertControllerSub addTextFieldWithConfigurationHandler:^(UITextField *textField) {
            UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0,0,80,30)];
            label.text = @"Slide ID";
            label.font = [UIFont systemFontOfSize:12];
            label.textColor = [UIColor darkGrayColor];
            textField.leftView = label;
            textField.leftViewMode = UITextFieldViewModeAlways;
            textField.placeholder = @"0 to 91";
            textField.keyboardType = UIKeyboardTypeNumberPad;
        }];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            NSString *text = alertControllerSub.textFields[0].text;
            NSInteger value = [self convertTextToInt:text];
            if (value >= 0) {
                dispatch_async(self->_gcd_buttonTappedQueue, ^{
                    [self startLoadingView:NO];
                    [Sample getDisplayResponseSample:SII_PM_DISPLAY_RESPONSE_SLIDE_LABEL paramId:value];
                    [self stopLoadingView];
                    [self showResult:[Sample getResultMessage]];
                });
            } else {
                [self showResult:@"can not covert to Int"];
            }
        }]];
        [alertControllerSub addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertControllerSub animated:YES completion:nil];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onSelectSmartLabelFileButtonClicked:(id)sender
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray *fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i < fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"sl"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"selecSmartLabelFile" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i < fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"sl"]) {
                [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                    [Sample selectSmartLabelFileSample:filePath];
                    [self showResult:[Sample getResultMessage]];
                }]];
            }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onReplaceTextDataButtonClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set map id and Text data"  message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"Map ID";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"Text data";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        if (value >= 0) {
            [Sample replaceSmartLabelTextDataSample:value text:text2];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onReplaceBarcodeDataButtonOnClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set map id and Barcode data"  message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"Map ID";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"Barcode data";
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        NSString *text2 = alertController.textFields[1].text;
        if (value >= 0) {
            [Sample replaceSmartLabelBarcodeDataSample:value text:text2];
            [self showResult:[Sample getResultMessage]];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (IBAction)onReplaceImageDataButtonOnClicked:(id)sender
{
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"set map id and image file" message:nil preferredStyle:UIAlertControllerStyleAlert];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField *textField) {
        textField.placeholder = @"Map ID";
        textField.keyboardType = UIKeyboardTypeNumberPad;
    }];
    [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
        NSString *text = alertController.textFields[0].text;
        NSInteger value = [self convertTextToInt:text];
        if (value >= 0) {
            [self showReplaceImageDataSelectFileView:value];
        } else {
            [self showResult:@"can not covert to Int"];
        }
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)showReplaceImageDataSelectFileView:(NSInteger)value
{
    NSFileManager *fileManager = [NSFileManager defaultManager];
    NSArray * fileList = [[NSArray alloc] initWithArray:[fileManager contentsOfDirectoryAtPath:DOCUMENTS_PATH error:nil]];
    BOOL fileExist = NO;
    for (int i=0; i < fileList.count; i++) {
        NSString *fileName = [fileList objectAtIndex:i];
        NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
        NSString *fileExtention = [filePath pathExtension];
        if ([fileExtention isEqualToString:@"bmp"] || [fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
            fileExist = YES;
        }
    }
    if (fileExist) {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"select file" message:nil preferredStyle:UIAlertControllerStyleAlert];
        for (int i=0; i < fileList.count; i++) {
            NSString *fileName = [fileList objectAtIndex:i];
            NSString *filePath= [NSString stringWithFormat:@"%@/%@", DOCUMENTS_PATH, fileName];
            NSString *fileExtention = [filePath pathExtension];
            if ([fileExtention isEqualToString:@"bmp"] || [fileExtention isEqualToString:@"jpg"] || [fileExtention isEqualToString:@"jpeg"] || [fileExtention isEqualToString:@"png"]) {
                    [alertController addAction:[UIAlertAction actionWithTitle:fileName style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
                        NSData *data = [[NSData alloc] initWithContentsOfFile:filePath];
                        UIImage *image = [[UIImage alloc] initWithData:data];
                        [Sample replaceSmartLabelImageDataSample:value image:image];
                        [self showResult:[Sample getResultMessage]];
                    }]];
                }
        }
        [alertController addAction:[UIAlertAction actionWithTitle:@"Cancel" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    } else {
        UIAlertController *alertController =  [UIAlertController alertControllerWithTitle:@"" message:@"File is not found" preferredStyle:UIAlertControllerStyleAlert];
        [alertController addAction:[UIAlertAction actionWithTitle:@"Close" style:UIAlertActionStyleCancel handler:^(UIAlertAction *action) {
        }]];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

- (IBAction)onPrintSmartLabelImageDataButtonOnClicked:(id)sender
{
    dispatch_async(_gcd_buttonTappedQueue, ^{
        [self startLoadingView:NO];
        [Sample printSmartLabelImageDataSample];
        [self stopLoadingView];
        [self showResult:[Sample getResultMessage]];
    });
}

- (IBAction)onEncodeSwitchValueChanged:(id)sender
{
    if ([sender isOn]) {
        _barcodeEncodeSwicthLabel.text = @"String";
    } else {
        _barcodeEncodeSwicthLabel.text = @"Binary";
    }
}

#pragma mark - Privert methods
- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    return YES;
}

- (void)configureUIButtons
{
    [self configureUIButton:_connectButton];
    [self configureUIButton:_disConnectButton];
    [self configureUIButton:_printPageModeButton];
    [self configureUIButton:_sendTextButton];
    [self configureUIButton:_sendTextExButton];
    [self configureUIButton:_printBarcodeButton];
    [self configureUIButton:_printPDF417Button];
    [self configureUIButton:_printQRcodeButton];
    [self configureUIButton:_printDataMatrixButton];
    [self configureUIButton:_printMaxiCodeButton];
    [self configureUIButton:_printGS1DataBarStackedButton];
    [self configureUIButton:_printGS1DataBarStackedOmnidirectionalButton];
    [self configureUIButton:_printGS1DataBarExpandedStackedButton];
    [self configureUIButton:_printAztecCodeButton];
    [self configureUIButton:_cutPaperButton];
    [self configureUIButton:_feedPositionButton];
    [self configureUIButton:_openDrawerButton];
    [self configureUIButton:_buzzerButton];
    [self configureUIButton:_externalBuzzerButton];
    [self configureUIButton:_sendBinaryButton];
    [self configureUIButton:_sendDataFileButton];
    [self configureUIButton:_getStatusButton];
    [self configureUIButton:_abortButton];
    [self configureUIButton:_registerLogoButton];
    [self configureUIButton:_printLogoButton];
    [self configureUIButton:_unregisterLogoButton];
    [self configureUIButton:_registerStyleSheetButton];
    [self configureUIButton:_unregisterStyleSheetButton];
    [self configureUIButton:_resetPrinterButton];
    [self configureUIButton:_getPrinterResponseButton];
    [self configureUIButton:_startDiscoveryPrinterButton];
    [self configureUIButton:_cancelDiscoveryPrinterButton];
    [self configureUIButton:_getFoundPrinterButton];
    [self configureUIButton:_controlTransactionButton];
    [self configureUIButton:_getVersionButton];
    [self configureUIButton:_sendTimeoutButton];
    [self configureUIButton:_receiveTimeoutButton];
    [self configureUIButton:_internationalCharacterButton];
    [self configureUIButton:_codePageButton];
    [self configureUIButton:_printerModelButton];
    [self configureUIButton:_portTypeButton];
    [self configureUIButton:_isConnectButton];
    [self configureUIButton:_socketKeepingTimeButton];
    [self configureUIButton:_defragmentButton];
    [self configureUIButton:_showTemplateButton];
    [self configureUIButton:_showSlideButton];
    [self configureUIButton:_enterStandbyModeButton];
    [self configureUIButton:_executeMacroButton];
    [self configureUIButton:_turnOnScreenButton];
    [self configureUIButton:_selectTemplateButton];
    [self configureUIButton:_setTemplateImageDataButton];
    [self configureUIButton:_selectTemplateTextObjectButton];
    [self configureUIButton:_setTemplateTextAlignmentButton];
    [self configureUIButton:_setTemplateTextLeftMarginButton];
    [self configureUIButton:_setTemplateTextLineSpacingButton];
    [self configureUIButton:_setTemplateTextBoldButton];
    [self configureUIButton:_setTemplateTextUnderlineButton];
    [self configureUIButton:_setTemplateTextSizeButton];
    [self configureUIButton:_setTemplateTextFontButton];
    [self configureUIButton:_setTemplateTextRegisteredFontButton];
    [self configureUIButton:_setTemplateTextRightSpacingButton];
    [self configureUIButton:_setTemplateTextColorButton];
    [self configureUIButton:_setTemplateTextDataButton];
    [self configureUIButton:_setTemplateBarcodeDataButton];
    [self configureUIButton:_setTemplateQrCodeDataButton];
    [self configureUIButton:_registerTemplateButton];
    [self configureUIButton:_unregisterTemplateButton];
    [self configureUIButton:_registerImageDataButton];
    [self configureUIButton:_unregisterImageDataButton];
    [self configureUIButton:_registerSlideDataButton];
    [self configureUIButton:_unregisterSlideDataButton];
    [self configureUIButton:_registerUserDefinedCharacterButton];
    [self configureUIButton:_unregisterUserDefinedCharacterButton];
    [self configureUIButton:_registerOptionFontButton];
    [self configureUIButton:_unregisterOptionFontButton];
    [self configureUIButton:_controlMacroRegistrationButton];
    [self configureUIButton:_getDisplayResponseButton];
    [self configureUIButton:_selectSmartLabelFileButton];
    [self configureUIButton:_replaceTextDataButton];
    [self configureUIButton:_replaceBarcodeDataButton];
    [self configureUIButton:_replaceImageDataButton];
    [self configureUIButton:_printSmartLabelImageDataButton];
}

- (void)configureUITextField
{
    _barcodeData.layer.borderColor = [[UIColor darkGrayColor] CGColor];
}

- (void)configureUIButton:(UIButton *)_button
{
    _button.layer.borderColor = [[UIColor colorWithRed:19/255.0 green:144/255.0 blue:255/255.0 alpha:1.0] CGColor];
    _button.layer.borderWidth = 1.0;
    _button.layer.cornerRadius = 5.0;
    _button.clipsToBounds = YES;
    _button.titleLabel.font = [UIFont systemFontOfSize:14];
}

-(void)configureLoadingView
{
    _loadingViewBackGraund = [[UIView alloc]init];
    _loadingViewBackGraund.backgroundColor = [[UIColor grayColor]colorWithAlphaComponent:0.5];
    _loadingViewBackGraund.frame = self.view.bounds;
    _loadingViewFrame = [[UIView alloc]init];
    if (@available(iOS 13.0, *)) {
        _loadingViewFrame.backgroundColor = [UIColor systemBackgroundColor];
    } else {
        _loadingViewFrame.backgroundColor = [UIColor whiteColor];
    }
    _loadingViewFrame.frame= CGRectMake(.0f, .0f, 130.0f, 130.0f);
    _loadingViewFrame.layer.cornerRadius = 5.0f;
    _loadingViewFrame.layer.position = CGPointMake(CGRectGetMidX(self.view.bounds), CGRectGetMidY(self.view.bounds));
    _loadingIndicator = [[UIActivityIndicatorView alloc]initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleLarge];
    _loadingIndicator.color = [UIColor colorWithRed:19/255.0 green:144/255.0 blue:255/255.0 alpha:1.0];
    _loadingIndicator.hidesWhenStopped = YES;
    _cancelButton = [UIButton buttonWithType:UIButtonTypeRoundedRect];
    _cancelButton.frame= CGRectMake(.0f, .0f, 80.0f, 30.0f);
    _cancelButton.layer.borderColor = [[UIColor colorWithRed:19/255.0 green:144/255.0 blue:255/255.0 alpha:1.0] CGColor];
    _cancelButton.layer.position = CGPointMake(CGRectGetMidX(_loadingViewFrame.bounds), 95.0f);
    _cancelButton.layer.borderWidth = 1.0f;
    _cancelButton.layer.cornerRadius = 15.0f;
    _cancelButton.clipsToBounds = YES;
    _cancelButton.titleLabel.font = [UIFont systemFontOfSize:12.f];
    [_cancelButton setTitle:@"Cancel" forState:UIControlStateNormal];
    [_cancelButton addTarget:self action:@selector(cancelButtonClicked:) forControlEvents:UIControlEventTouchDown];
    [_loadingViewFrame addSubview:_cancelButton];
    [_loadingViewFrame addSubview:_loadingIndicator];
    [_loadingViewBackGraund addSubview:_loadingViewFrame];
    [self.view addSubview:_loadingViewBackGraund];
    _loadingViewBackGraund.hidden = YES;
}

-(void)startLoadingView:(BOOL)cancelButtonEnable
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [self->_cancelButton removeFromSuperview];
        if (cancelButtonEnable) {
            [self->_loadingViewFrame addSubview:self->_cancelButton];
            self->_loadingIndicator.layer.position = CGPointMake(CGRectGetMidX(self->_loadingViewFrame.bounds), 50.0f);
        } else {
            self->_loadingIndicator.layer.position = CGPointMake(CGRectGetMidX(self->_loadingViewFrame.bounds), CGRectGetMidY(self->_loadingViewFrame.bounds));
        }
        [self->_loadingIndicator startAnimating];
        self->_loadingViewBackGraund.hidden = NO;
    });
}

-(void)stopLoadingView
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [self->_loadingIndicator stopAnimating];
        self->_loadingViewBackGraund.hidden = YES;
    });
}

- (void)cancelButtonClicked:(id)sender
{
    [Sample cancelDiscoveryPrinterSample];
}

-(void)showResult:(NSString *)resultText
{
    dispatch_async(dispatch_get_main_queue(), ^{
        if ([resultText hasPrefix:@"Exception:"]) {
            NSString *message = [resultText substringFromIndex:10];
            UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"Exception" message:message preferredStyle:UIAlertControllerStyleAlert];
            [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            }]];
            [self presentViewController:alertController animated:YES completion:nil];
        } else {
            UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"" message:resultText preferredStyle:UIAlertControllerStyleAlert];
            [alertController addAction:[UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:^(UIAlertAction *action) {
            }]];
            [self presentViewController:alertController animated:YES completion:nil];
        }
    });
}

-(void)saveDefault:(id)object key:(NSString *)key
{
    NSUserDefaults *myDefaults = [NSUserDefaults standardUserDefaults];
    [myDefaults setObject:object forKey:key];
    [myDefaults synchronize];
}

- (NSData *)covertHexStringToBinary:(NSString *)hexString
{
    if (hexString.length % 2 > 0) {
        return nil;
    }
    hexString = [hexString uppercaseString];
    for (int i=0;i<[hexString length];i++) {
        unichar hex_char1 = [hexString characterAtIndex:i];
        if (hex_char1 >= '0' && hex_char1 <= '9') {
        } else if (hex_char1 >= 'A' && hex_char1 <= 'F') {
        } else {
            return nil;
        }
    }
    UInt8 buf[hexString.length / 2];
    for (int i=0;i<[hexString length];i+=2) {
        unichar hex_char1 = [hexString characterAtIndex:i];
        int int_ch1;
        if (hex_char1 >= '0' && hex_char1 <= '9') {
            int_ch1 = (hex_char1 - 48) * 16;
        } else if (hex_char1 >= 'A' && hex_char1 <= 'F') {
            int_ch1 = (hex_char1 - 55) * 16;
        } else {
            return [NSData dataWithBytes:buf length:0];
        }
        unichar hex_char2 = [hexString characterAtIndex:i + 1];
        int int_ch2;
        if (hex_char2 >= '0' && hex_char2 <= '9') {
            int_ch2 = hex_char2 - 48;
        } else if (hex_char2 >= 'A' && hex_char2 <= 'F') {
            int_ch2 = hex_char2 - 55;
        } else {
            int_ch2 = hex_char2 - 87;
        }
        buf[i / 2] = int_ch1 + int_ch2;
    }
    return [NSData dataWithBytes:buf length:sizeof(buf)];
}

- (NSInteger)convertTextToInt:(NSString *)text
{
    BOOL convertInt = YES;
    if (text.length > 0) {
        for (NSInteger i=0; i<text.length; i++) {
            unichar c = [text characterAtIndex:i];
            if ((i == 0) && (c == 45)) {
                continue;
            }
            if (c < 48 || c > 57) {
                convertInt = NO;
            }
        }
    } else {
        convertInt = NO;
    }
    if (convertInt) {
        return [text integerValue];
    } else {
        return INT_MIN;
    }
}

#pragma mark SIIPrinterManagerDelegate
- (void)didStatusChange:(SIIPrinterManager *)printerManager status:(NSInteger)status
{
    dispatch_async(dispatch_get_main_queue(), ^{
        self->_lastStatus.text = [NSString stringWithFormat:@"0x%02lX\n", (long)status];
    });
}

- (void)didBarcodeScannerReadData:(SIIPrinterManager *)printerManager data:(NSData *)data {
    dispatch_async(dispatch_get_main_queue(), ^{
        if (self->_barcodeEncodeSwitch.isOn) {
            NSString *endodedString = [[NSString alloc] initWithData:data encoding:NSShiftJISStringEncoding];
            if (endodedString) {
                self->_barcodeData.text = endodedString;
            } else {
                self->_barcodeData.text = @"Encoding failed!!";
            }
        } else {
            UInt8 buf[data.length];
            [data getBytes:buf length:data.length];
            NSMutableString *str = [NSMutableString stringWithCapacity:10];
            for (int i = 0; i < data.length; i++) {
                [str appendString:[NSString stringWithFormat:@"%02lX", (long)buf[i]]];
            }
            self->_barcodeData.text = str;
        }
    });
}

- (void)didBarcodeScannerChangedOnline:(SIIPrinterManager *)printerManager {
    dispatch_async(dispatch_get_main_queue(), ^{
        self->_barcodeStatus.text = @"Online";
    });
}

- (void)didBarcodeScannerChangedOffline:(SIIPrinterManager *)printerManager {
    dispatch_async(dispatch_get_main_queue(), ^{
        self->_barcodeStatus.text = @"Offline";
    });
}

@end
