//
//  Sample.swift
//  SiiLibSample
//

import UIKit

class Sample {
    fileprivate static var _printer: SIIPrinterManagerWrapper!
    fileprivate static var _label: SIISmartLabelManagerWrapper!
    fileprivate static var _printerDiscoveryCompletion  = false
    fileprivate static var _resultMessage = ""
    
    internal static let TRANSACTION_START: Int32 = 1
    internal static let TRANSACTION_PRINT: Int32 = 2
    internal static let TRANSACTION_CLEAR: Int32 = 3
    internal static let CUTTINGMETHOD_FULL: Int32 = 1
    internal static let CUTTINGMETHOD_PARTIAL: Int32 = 2
    internal static let CUTTINGMETHOD_FULL_NO_FEED: Int32 = 3
    internal static let CUTTINGMETHOD_PARTIAL_NO_FEED: Int32 = 4
    internal static let ALIGNMENT_LEFT: Int32 = 1
    internal static let ALIGNMENT_CENTER: Int32 = 2
    internal static let ALIGNMENT_RIGHT: Int32 = 3
    internal static let BOLD: Int32 = 1
    internal static let BOLD_CANCEL: Int32 = 2
    internal static let UNDERLINE_1: Int32 = 1
    internal static let UNDERLINE_CANCEL: Int32 = 2
    internal static let VARTICAL_1_HORIZONTAL_1: Int32 = 1
    internal static let VARTICAL_1_HORIZONTAL_2: Int32 = 2
    internal static let VARTICAL_1_HORIZONTAL_3: Int32 = 3
    internal static let VARTICAL_1_HORIZONTAL_4: Int32 = 4
    internal static let VARTICAL_2_HORIZONTAL_1: Int32 = 5
    internal static let VARTICAL_2_HORIZONTAL_2: Int32 = 6
    internal static let VARTICAL_2_HORIZONTAL_3: Int32 = 7
    internal static let VARTICAL_2_HORIZONTAL_4: Int32 = 8
    internal static let VARTICAL_3_HORIZONTAL_1: Int32 = 9
    internal static let VARTICAL_3_HORIZONTAL_2: Int32 = 10
    internal static let VARTICAL_3_HORIZONTAL_3: Int32 = 11
    internal static let VARTICAL_3_HORIZONTAL_4: Int32 = 12
    internal static let VARTICAL_4_HORIZONTAL_1: Int32 = 13
    internal static let VARTICAL_4_HORIZONTAL_2: Int32 = 14
    internal static let VARTICAL_4_HORIZONTAL_3: Int32 = 15
    internal static let VARTICAL_4_HORIZONTAL_4: Int32 = 16
    internal static let FONT_A: Int32 = 1
    internal static let FONT_B: Int32 = 2
    internal static let FONT_STANDARD: Int32 = 1
    internal static let FONT_OPTION: Int32 = 2
    internal static let MACRO_REGISTRATION_START: Int32 = 1
    internal static let MACRO_REGISTRATION_REGIST: Int32 = 2
    internal static let MACRO_REGISTRATION_CLEAR: Int32 = 3

    static func InitialSetting(view: ViewController) {
        self._printer = SIIPrinterManagerWrapper()
        self._label = SIISmartLabelManagerWrapper()
        self._printerDiscoveryCompletion = false
        self._resultMessage = ""
        self._printer.delegate = view
    }

    static func getResultString() -> String {
        return self._resultMessage
    }

    static func connectSample(_ model: Int32, _ address: String, _ type: Int32) -> Bool {
        do {
            try self._printer.connect(model, address: address, portType: type)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func disconnectSample() -> Bool {
        do {
            try self._printer.disconnect()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func sendTextSample(_ text: String) -> Bool {
        do {
            try self._printer.sendText(text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func sendTextExSample(_ text: String) -> Bool {
        do {
            try self._printer.sendTextEx(
                text, 
                bold: CharacterBold.SII_PM_BOLD, 
                underline: CharacterUnderline.SII_PM_UNDERLINE_1, 
                font: CharacterFont.SII_PM_FONT_A, 
                scale: CharacterScale.SII_PM_VARTICAL_2_HORIZONTAL_2
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printBarcodeSample() -> Bool {
        var success = true
        if !barcode_upca() {
            success = false
        }
        if !barcode_upce() {
            success = false
        }
        if !barcode_ean13() {
            success = false
        }
        if !barcode_ean8() {
            success = false
        }
        if !barcode_code39() {
            success = false
        }
        if self._printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S245
        && self._printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S445 {
            if !barcode_code93() {
                success = false
            }
        }
        if !barcode_code128() {
            success = false
        }
        if !barcode_itf() {
            success = false
        }
        if !barcode_codabar() {
            success = false
        }
        if self._printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S245
        && self._printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S445 {
            if !barcode_ean13_addon() {
                success = false
            }
        }
        if self._printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S245
        && self._printer.printerModel !=  SII_PM_PRINTER_MODEL_DPU_S445
        && self._printer.printerModel !=  SII_PM_PRINTER_MODEL_RP_D10
        && self._printer.printerModel !=  SII_PM_PRINTER_MODEL_RP_E10 {
            if !barcode_gs1_omini_directional() {
                success = false
            }
            if !barcode_gs1_truncated() {
                success = false
            }
            if !barcode_gs1_limited() {
                success = false
            }
            if !barcode_gs1_expanded() {
                success = false
            }
        }
        if success {
            self._resultMessage = "Succeeded"
            return true
        } else {
            self._resultMessage = "Failed"
            return false
        }
    }

    static func barcode_upca() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_UPC_A, 
                text: "12345678901", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_upce() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_UPC_E, 
                text: "01234500005", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_ean13() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_EAN13, 
                text: "123456789012", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_ean8() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_EAN8, 
                text: "1234567", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_code39() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_CODE39, 
                text: "1234", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_code93() -> Bool {
        do {
            let bytes: [UInt8] = [0x01, 0x02, 0x03, 0x04, 0x0b, 0x0c, 0x0d, 0xff]
            let data = Data(bytes: bytes)
            try self._printer.printBarcode(
                .SII_PM_BARCODE_CODE93, 
                data: data, 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_code128() -> Bool {
        do {
            let bytes: [UInt8] = [0x67, 0x01, 0x02, 0x03, 0x04, 0x67]
            let data = Data(bytes: bytes)
            try self._printer.printBarcode(
                .SII_PM_BARCODE_CODE128, 
                data: data, 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_itf() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_ITF, 
                text: "12345678", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_codabar() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_CODABAR, 
                text: "A123456A", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_ean13_addon() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_EAN13_ADDON, 
                text: "12345678901234", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_2, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_gs1_omini_directional() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_GS1_OMNI_DIRECTIONAL, 
                text: "1234567890123", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 99, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_gs1_truncated() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_GS1_TRUNCATED, 
                text: "1234567890123", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_gs1_limited() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_GS1_TRUNCATED, 
                text: "1234567890123", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 50, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func barcode_gs1_expanded() -> Bool {
        do {
            try self._printer.printBarcode(
                .SII_PM_BARCODE_GS1_EXPANDED, 
                text: "123456", 
                moduleSize: .SII_PM_BARCODE_MODULE_WIDTH_3, 
                moduleHeight: 102, 
                hriPosition: .SII_PM_HRI_POSITION_ABOVE, 
                hriFont: .SII_PM_FONT_A, 
                alignment: .SII_PM_ALIGNMENT_LEFT)
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printPDF417Sample() -> Bool {
        do {
            try self._printer.printPDF417(
                "123456789ABCD", 
                errorCorrection: .SII_PM_PDF417_ERROR_CORRECTION_3, 
                row: 0,
                column: 0,
                moduleSize: .SII_PM_PDF417_MODULE_WIDTH_3, 
                moduleHeight: 10,
                alignment: .SII_PM_ALIGNMENT_LEFT, 
                pdf417Symbol: .SII_PM_PDF417_STANDARD
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printQRcodeSample() -> Bool {
        do {
            try self._printer.printQRcode(
                "123456789ABCD", 
                errorCorrection: .SII_PM_QR_ERROR_CORRECTION_M, 
                moduleSize: .SII_PM_QR_MODULE_SIZE_6, 
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printDataMatrixSample() -> Bool {
        do {
            try self._printer.printDataMatrix(
                "0123456789", 
                dataMatrixModule: .SII_PM_DATA_MATRIX_AUTO, 
                moduleSize: .SII_PM_DATAMATRIX_MODULE_SIZE_6, 
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printMaxiCodeSample() -> Bool {
        do {
            try self._printer.printMaxiCode(
                "122333444455555ABC0123456789DEF", 
                maxiCodeMode: .SII_PM_MAXI_CODE_2, 
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printGS1DataBarStackedSample() -> Bool {
        do {
            try self._printer.printGS1DataBarStacked(
                "1230123456789", 
                moduleSize: .SII_PM_GS1DATABAR_MODULE_SIZE_6, 
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printGS1DataBarStackedOmnidirectionalSample() -> Bool {
        do {
            try self._printer.printGS1DataBarStackedOmnidirectional(
                "1230123456789", 
                moduleHeight: 33, 
                moduleSize: .SII_PM_GS1DATABAR_MODULE_SIZE_6, 
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printGS1DataBarExpandedStackedSample() -> Bool {
        do {
            try self._printer.printGS1DataBarExpandedStacked(
                "ABCDEFG", 
                column: 2, 
                moduleSize: .SII_PM_GS1DATABAR_MODULE_SIZE_6, 
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printAztecCodeSample() -> Bool {
        do {
            try self._printer.printAztecCode(
                "1234567890",
                layer: 0,
                errorCorrection: 0,
                moduleSize: .SII_PM_AZTECCODE_MODULE_SIZE_6,
                aztecSymbol: .SII_PM_AZTECCODE_COMPACT,
                alignment: .SII_PM_ALIGNMENT_LEFT
            )
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func cutPaperSample(_ cuttingMethod: Int32) -> Bool {
        do {
            if cuttingMethod == Sample.CUTTINGMETHOD_FULL {
                try self._printer.cutPaper(.SII_PM_CUT_FULL)
                self._resultMessage = "Succeeded"
                return true
            } else if cuttingMethod == Sample.CUTTINGMETHOD_PARTIAL {
                try self._printer.cutPaper(.SII_PM_CUT_PARTIAL)
                self._resultMessage = "Succeeded"
                return true
            } else if cuttingMethod == Sample.CUTTINGMETHOD_FULL_NO_FEED {
                try self._printer.cutPaper(.SII_PM_CUT_FULL_NO_FEED)
                self._resultMessage = "Succeeded"
                return true
            } else if cuttingMethod == Sample.CUTTINGMETHOD_PARTIAL_NO_FEED {
                try self._printer.cutPaper(.SII_PM_CUT_PARTIAL_NO_FEED)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to cutPaper"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func feedPositionSample() -> Bool {
        do {
            try self._printer.feedPosition(FeedPosition.SII_PM_FEED_CUTTER)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func openDrawerSample() -> Bool {
        do {
            try self._printer.openDrawer(.SII_PM_DRAWER_1, onOffTime: .SII_PM_ON_OFF_TIME_500)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func buzzerSample() -> Bool {
        do {
            try self._printer.buzzer(100, offTime: 100)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func externalBuzzerSample() -> Bool {
        do {
            try self._printer.externalBuzzer(.SII_PM_BUZZER_PATTERN_1, buzzerCount: 1)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func sendBinarySample(_ data: Data) -> Bool {
        do {
            try self._printer.sendBinary(data)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func sendDataFileSample(_ filePath: String) -> Bool {
        do {
            try self._printer.sendDataFile(filePath, alignment:.SII_PM_ALIGNMENT_LEFT)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func getStatusSample() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getStatus(&val)
            self._resultMessage = String(format: "getStatus:0x%02lX", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func abortSample() -> Bool {
        do {
            try self._printer.abort()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func registerLogoSample(_ filePath: String) -> Bool {
        var logoid = "$$"
        if self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445 {
            logoid = "2"
        }
        do {
            try self._printer.registerLogo(filePath, logoId: logoid, dithering: .SII_PM_DITHERING_ERRORDIFFUSION)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func printLogoSample() -> Bool {
        var logoid = "$$"
        if self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445 {
            logoid = "2"
        }
        do {
            try self._printer.printLogo(logoid)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func unregisterLogoSample() -> Bool {
        var logoid = "$$"
        if self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445 {
            logoid = "2"
        }
        do {
            try self._printer.unregisterLogo(logoid)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func registerStyleSheetSample(_ filePath: String) -> Bool {
        do {
            try self._printer.registerStyleSheet(filePath, cssId:1)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func unregisterStyleSheetSample() -> Bool {
        do {
            try self._printer.unregisterStyleSheet(1)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func resetPrinterSample() -> Bool {
        do {
            try self._printer.resetPrinter()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func getPrinterResponseSample(_ responseId: Int32) -> Bool {
        if responseId == SII_PM_PRINTER_RESPONSE_REQUEST {
            return response_request()
        } else if responseId == SII_PM_PRINTER_RESPONSE_USER_AREA {
            return response_userarea()
        } else if responseId == SII_PM_PRINTER_RESPONSE_ARRANGE_USER_AREA {
            return response_arrangeuserarea()
        } else if responseId == SII_PM_PRINTER_RESPONSE_NV_GRAPHICS {
            return response_nvgraphics()
        } else if responseId == SII_PM_PRINTER_RESPONSE_KEY_CODE {
            return response_keycode()
        } else if responseId == SII_PM_PRINTER_RESPONSE_BATTERY_STATUS {
            return response_batterystatus()
        } else {
            self._resultMessage = "responseId invalid\n"
            return false
        }
    }

    static func response_request() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getPrinterResponse(SII_PM_PRINTER_RESPONSE_REQUEST, param: 0x01, response: &val)
            self._resultMessage = String(format: "REQUEST:0x%02lX", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func response_userarea() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getPrinterResponse(SII_PM_PRINTER_RESPONSE_USER_AREA, response: &val)
            self._resultMessage = String(format: "USER_AREA:%ld", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func response_arrangeuserarea() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getPrinterResponse(SII_PM_PRINTER_RESPONSE_ARRANGE_USER_AREA, response: &val)
            self._resultMessage = String(format: "ARRANGE_USER_AREA:%ld", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func response_nvgraphics() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getPrinterResponse(SII_PM_PRINTER_RESPONSE_NV_GRAPHICS, response: &val)
            self._resultMessage = String(format: "NV_GRAPHICS:%ld", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func response_keycode() -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getPrinterResponse(SII_PM_PRINTER_RESPONSE_KEY_CODE, responseArray: ret!)
            var resultText = "KEY_CODE:"
            if 0 < ret.count {
                for i in 0...ret.count-1 {
                    resultText = resultText + String(describing: ret[i]) + ", "
                }
            }
            self._resultMessage = resultText
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func response_batterystatus() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getPrinterResponse(SII_PM_PRINTER_RESPONSE_BATTERY_STATUS, response: &val)
            let ret: Int32 = Int32(val[0])
            var resultText:String = ""
            if self._printer.printerModel == SII_PM_PRINTER_MODEL_MP_B20 || self._printer.printerModel == SII_PM_PRINTER_MODEL_MP_B30 || self._printer.printerModel == SII_PM_PRINTER_MODEL_MP_B30L {
                if ret == SII_PM_BATTERY_STATUS_FULL {
                    resultText = "BATTERY_STATUS:FULL"
                } else if ret == SII_PM_BATTERY_STATUS_MIDDLE {
                    resultText = "BATTERY_STATUS:MIDDLE"
                } else if ret == SII_PM_BATTERY_STATUS_LOW {
                    resultText = "BATTERY_STATUS:LOW"
                } else if ret == SII_PM_BATTERY_STATUS_EMPTY {
                    resultText = "BATTERY_STATUS:EMPTY"
                } else {
                    resultText = String(format: "BATTERY_STATUS:%ld", ret)
                }
            } else if self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S245 || self._printer.printerModel == SII_PM_PRINTER_MODEL_DPU_S445 {
                if ret == 0 {
                    resultText = "BATTERY_STATUS:8.0 V or higher"
                } else if ret == 1 {
                    resultText = "BATTERY_STATUS:7.5 V to 8.0 V"
                } else if ret == 2 {
                    resultText = "BATTERY_STATUS:7.0 V to 7.5 V"
                } else if ret == 3 {
                    resultText = "BATTERY_STATUS:Lower than 7.0 V"
                } else {
                    resultText = String(format: "BATTERY_STATUS:%ld", ret)
                }
            } else {
                resultText = String(format: "BATTERY_STATUS:%ld", ret)
            }
            self._resultMessage = resultText
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func startLanDiscoveryPrinterSample(_ retryCount: Int, _ timeout: Int) {
        self._printerDiscoveryCompletion  = false
        self._printer.startDiscoveryPrinter(retryCount, timeout: timeout, completion: { (printerList:[Any]!) in
            self._printerDiscoveryCompletion  = true
        })
        self._resultMessage = "Succeeded"
    }

    static func getPrinterDiscoveryComletion() -> Bool {
        return self._printerDiscoveryCompletion 
    }

    static func startBluetoothDiscoveryPrinterSample() {
        self._printer.startDiscoveryPrinter(nil, completion: nil)
    }

    static func cancelDiscoveryPrinterSample() {
        self._printer.cancelDiscoveryPrinter()
        self._resultMessage = "Succeeded"
    }

    static func getFoundPrinterSample() -> [Any] {
        var foundPrinterList = [Any]()
        let foundPrinterListOptional = self._printer.getFoundPrinter()
        if let foundPrinterListBinded = foundPrinterListOptional {
            foundPrinterList = foundPrinterListBinded
        }
        return foundPrinterList
    }

    static func controlTransactionSample(_ transactionFunction: Int32) -> Bool {
        do {
            if transactionFunction == Sample.TRANSACTION_START {
                try self._printer.controlTransaction(.SII_PM_TRANSACTION_START)
                self._resultMessage = "Succeeded"
                return true
            } else if transactionFunction == Sample.TRANSACTION_PRINT {
                try self._printer.controlTransaction(.SII_PM_TRANSACTION_PRINT)
                self._resultMessage = "Succeeded"
                return true
            } else if transactionFunction == Sample.TRANSACTION_CLEAR {
                try self._printer.controlTransaction(.SII_PM_TRANSACTION_CLEAR)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to controlTransaction"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func getVersionSample() {
        self._resultMessage = self._printer.getVersion()
        return
    }

    static func get_sendTimeoutSample() -> Int32 {
        let timeout = self._printer.sendTimeout
        return timeout
    }

    static func set_sendTimeoutSample(_ timeout: Int32) {
        self._printer.sendTimeout = timeout
        if self._printer.sendTimeout == timeout {
            self._resultMessage = "Succeeded"
        } else {
            self._resultMessage = "sendTimeout is rounded"
        }
    }

    static func get_receiveTimeoutSample() -> Int32 {
        let timeout = self._printer.receiveTimeout
        return timeout
    }

    static func set_receiveTimeoutSample(_ timeout: Int32) {
        self._printer.receiveTimeout = timeout
        if self._printer.receiveTimeout == timeout {
            self._resultMessage = "Succeeded"
        } else {
            self._resultMessage = "receiveTimeout is rounded"
        }
    }

    static func get_internationalCharacterSample() {
        let internationalCharacter = self._printer.internationalCharacter
        if internationalCharacter == SII_PM_COUNTRY_USA {
            self._resultMessage = "internationalCharacter:\nUSA"
        } else if internationalCharacter == SII_PM_COUNTRY_FRANCE {
            self._resultMessage = "internationalCharacter:\nFRANCE"
        } else if internationalCharacter == SII_PM_COUNTRY_GERMANY {
            self._resultMessage = "internationalCharacter:\nGERMANY"
        } else if internationalCharacter == SII_PM_COUNTRY_ENGLAND {
            self._resultMessage = "internationalCharacter:\nENGLAND"
        } else if internationalCharacter == SII_PM_COUNTRY_DENMARK_1 {
            self._resultMessage = "internationalCharacter:\nDENMARK_1"
        } else if internationalCharacter == SII_PM_COUNTRY_SWEDEN {
            self._resultMessage = "internationalCharacter:\nSWEDEN"
        } else if internationalCharacter == SII_PM_COUNTRY_ITALY {
            self._resultMessage = "internationalCharacter:\nITALY"
        } else if internationalCharacter == SII_PM_COUNTRY_SPAIN {
            self._resultMessage = "internationalCharacter:\nSPAIN"
        } else if internationalCharacter == SII_PM_COUNTRY_JAPAN {
            self._resultMessage = "internationalCharacter:\nJAPAN"
        } else if internationalCharacter == SII_PM_COUNTRY_NORWAY {
            self._resultMessage = "internationalCharacter:\nNORWAY"
        } else if internationalCharacter == SII_PM_COUNTRY_DENMARK_2 {
            self._resultMessage = "internationalCharacter:\nDENMARK_2"
        } else if internationalCharacter == SII_PM_COUNTRY_SPAIN_2 {
            self._resultMessage = "internationalCharacter:\nSPAIN_2"
        } else if internationalCharacter == SII_PM_COUNTRY_LATIN_AMERICA {
            self._resultMessage = "internationalCharacter:\nLATIN_AMERICA"
        } else if internationalCharacter == SII_PM_COUNTRY_ARABIA {
            self._resultMessage = "internationalCharacter:\nARABIA"
        } else {
            self._resultMessage = "internationalCharacter is invalid"
        }
    }

    static func set_internationalCharacterSample(_ internationalCharacter: Int32) {
        self._printer.internationalCharacter = internationalCharacter
        if self._printer.internationalCharacter == internationalCharacter {
            self._resultMessage = "Succeeded"
        } else {
            self._resultMessage = "Faile to set internationalCharacter"
        }
    }

    static func get_codePageSample() {
        let codePage = self._printer.codePage
        if codePage == SII_PM_CODE_PAGE_437 {
            self._resultMessage = "codePage:codePage 437"
        } else if codePage == SII_PM_CODE_PAGE_KATAKANA {
            self._resultMessage = "codePage:codePage KATAKANA"
        } else if codePage == SII_PM_CODE_PAGE_850 {
            self._resultMessage = "codePage:codePage 850"
        } else if codePage == SII_PM_CODE_PAGE_860 {
            self._resultMessage = "codePage:codePage 860"
        } else if codePage == SII_PM_CODE_PAGE_863 {
            self._resultMessage = "codePage:codePage 863"
        } else if codePage == SII_PM_CODE_PAGE_865 {
            self._resultMessage = "codePage:codePage 865"
        } else if codePage == SII_PM_CODE_PAGE_857 {
            self._resultMessage = "codePage:codePage 857"
        } else if codePage == SII_PM_CODE_PAGE_737 {
            self._resultMessage = "codePage:codePage 737"
        } else if codePage == SII_PM_CODE_PAGE_1252 {
            self._resultMessage = "codePage:codePage 1252"
        } else if codePage == SII_PM_CODE_PAGE_866 {
            self._resultMessage = "codePage:codePage 866"
        } else if codePage == SII_PM_CODE_PAGE_852 {
            self._resultMessage = "codePage:codePage 852"
        } else if codePage == SII_PM_CODE_PAGE_858 {
            self._resultMessage = "codePage:codePage 858"
        } else if codePage == SII_PM_CODE_PAGE_855 {
            self._resultMessage = "codePage:codePage 855"
        } else if codePage == SII_PM_CODE_PAGE_864 {
            self._resultMessage = "codePage:codePage 864"
        } else if codePage == SII_PM_CODE_PAGE_1250 {
            self._resultMessage = "codePage:codePage 1250"
        } else if codePage == SII_PM_CODE_PAGE_1251 {
            self._resultMessage = "codePage:codePage 1251"
        } else if codePage == SII_PM_CODE_PAGE_1253 {
            self._resultMessage = "codePage:codePage 1253"
        } else if codePage == SII_PM_CODE_PAGE_1254 {
            self._resultMessage = "codePage:codePage 1254"
        } else {
            self._resultMessage = "codePage is invalid"
        }
    }

    static func set_codePageSample(_ codePage: Int32) {
        self._printer.codePage = codePage
        if self._printer.codePage == codePage {
            self._resultMessage = "Succeeded"
        } else {
            self._resultMessage = "Faile to set codePage"
        }
    }

    static func get_printerModelSample() {
        let printerModel = self._printer.printerModel
        if printerModel == SII_PM_PRINTER_MODEL_DPU_S445 {
            self._resultMessage = "printerModel:DPU-S445"
        } else if printerModel == SII_PM_PRINTER_MODEL_DPU_S245 {
            self._resultMessage = "printerModel:DPU-S245"
        } else if printerModel == SII_PM_PRINTER_MODEL_RP_E10 {
            self._resultMessage = "printerModel:RP-E10"
        } else if printerModel == SII_PM_PRINTER_MODEL_RP_D10 {
            self._resultMessage = "printerModel:RP-D10"
        } else if printerModel == SII_PM_PRINTER_MODEL_MP_B20 {
            self._resultMessage = "printerModel:MP-B20"
        } else if printerModel == SII_PM_PRINTER_MODEL_MP_B30 {
            self._resultMessage = "printerModel:MP-B30"
        } else if printerModel == SII_PM_PRINTER_MODEL_RP_F10 {
            self._resultMessage = "printerModel:RP-F10"
        } else if printerModel == SII_PM_PRINTER_MODEL_MP_B30L {
            self._resultMessage = "printerModel:MP-B30L"
        } else if printerModel == SII_PM_PRINTER_MODEL_SLP720RT {
            self._resultMessage = "printerModel:SLP720RT"
        } else {
            self._resultMessage = "printerModel:printer is not connected"
        }
    }

    static func get_portTypeSample() {
        let portType = self._printer.portType
        if portType == SII_PM_PRINTER_PORT_TYPE_BLUETOOTH {
            self._resultMessage = "portType:Bluetooth"
        } else if portType == SII_PM_PRINTER_PORT_TYPE_TCP {
            self._resultMessage = "portType:TCP/IP"
        } else if portType == SII_PM_PRINTER_PORT_TYPE_USB {
            self._resultMessage = "portType:USB"
        } else {
            self._resultMessage = "portType:printer is not connected"
        }
    }

    static func get_isConnectSample() {
        let isConnect = self._printer.isConnect
        if isConnect {
            self._resultMessage = "isConnect:YES"
        } else {
            self._resultMessage = "isConnect:NO"
        }
    }

    static func get_socketKeepingTimeSample() -> Int32 {
        let socketKeepingTime = self._printer.socketKeepingTime
        return socketKeepingTime
    }

    static func set_socketKeepingTimeSample(_ socketKeepingTime: Int32) {
        self._printer.socketKeepingTime = socketKeepingTime
        if self._printer.socketKeepingTime == socketKeepingTime {
            self._resultMessage = "Succeeded"
        } else {
            self._resultMessage = "socketKeepingTime is rounded"
        }
    }

    // MARK: - Display apis -
    static func defragmentSample() -> Bool {
        do {
            try self._printer.defragment()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func initializeMemoryAreaSample() -> Bool {
        do {
            try self._printer.initializeMemoryArea()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func showTemplateSample(_ time_ms: Int32) -> Bool {
        do {
            try self._printer.showTemplate(time_ms)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func showSlideSample(_ slideID: Int32, _ time_ms: Int32) -> Bool {
        do {
            try self._printer.showSlide(slideID, time_ms: time_ms)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func enterStandbyModeSample() -> Bool {
        do {
            try self._printer.enterStandbyMode()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func executeMacroSample(_ macroID: Int32, _ repeatCount: Int32) -> Bool {
        do {
            try self._printer.executeMacro(macroID, repeatCount: repeatCount)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func turnOnScreenSample(_ isOn: Bool) -> Bool {
        do {
            try self._printer.turn(onScreen: isOn)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func selectTemplateSample(_ templateID: Int32, _ slideID: Int32) -> Bool {
        do {
            try self._printer.selectTemplate(templateID, slideID: slideID)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateImageDataSample(_ mapID: Int32, _ imageID: Int32) -> Bool {
        do {
            try self._printer.setTemplateImageData(mapID, imageID: imageID)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func selectTemplateTextObjectSample(_ mapID: Int32) -> Bool {
        do {
            try self._printer.selectTemplateTextObject(mapID)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextAlignmentSample(_ alignment: Int32) -> Bool {
        do {
            if alignment == Sample.ALIGNMENT_LEFT {
                try self._printer.setTemplateTextAlignment(.SII_PM_ALIGNMENT_LEFT)
                self._resultMessage = "Succeeded"
                return true
            } else if alignment == Sample.ALIGNMENT_CENTER {
                try self._printer.setTemplateTextAlignment(.SII_PM_ALIGNMENT_CENTER)
                self._resultMessage = "Succeeded"
                return true
            } else if alignment == Sample.ALIGNMENT_RIGHT {
                try self._printer.setTemplateTextAlignment(.SII_PM_ALIGNMENT_RIGHT)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to setTemplateTextAlignment"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextLeftMarginSample(_ margin: Int32) -> Bool {
        do {
            try self._printer.setTemplateTextLeftMargin(margin)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextLineSpacingSample(_ spacing: Int32) -> Bool {
        do {
            try self._printer.setTemplateTextLineSpacing(spacing)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextBoldSample(_ bold: Int32) -> Bool {
        do {
            if bold == Sample.BOLD {
                try self._printer.setTemplateTextBold(.SII_PM_BOLD)
                self._resultMessage = "Succeeded"
                return true
            } else if bold == Sample.BOLD_CANCEL {
                try self._printer.setTemplateTextBold(.SII_PM_BOLD_CANCEL)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to setTemplateTextBold"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextUnderlineSample(_ underline: Int32) -> Bool {
        do {
            if underline == Sample.UNDERLINE_1 {
                try self._printer.setTemplateTextUnderline(.SII_PM_UNDERLINE_1)
                self._resultMessage = "Succeeded"
                return true
            } else if underline == Sample.UNDERLINE_CANCEL {
                try self._printer.setTemplateTextUnderline(.SII_PM_UNDERLINE_CANCEL)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to setTemplateTextUnderline"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextSizeSample(_ scale: Int32) -> Bool {
        do {
            if scale == Sample.VARTICAL_1_HORIZONTAL_1 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_1_HORIZONTAL_1)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_2_HORIZONTAL_1 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_2_HORIZONTAL_1)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_3_HORIZONTAL_1 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_3_HORIZONTAL_1)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_4_HORIZONTAL_1 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_4_HORIZONTAL_1)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_1_HORIZONTAL_2 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_1_HORIZONTAL_2)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_2_HORIZONTAL_2 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_2_HORIZONTAL_2)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_3_HORIZONTAL_2 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_3_HORIZONTAL_2)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_4_HORIZONTAL_2 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_4_HORIZONTAL_2)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_1_HORIZONTAL_3 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_1_HORIZONTAL_3)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_2_HORIZONTAL_3 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_2_HORIZONTAL_3)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_3_HORIZONTAL_3 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_3_HORIZONTAL_3)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_4_HORIZONTAL_3 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_4_HORIZONTAL_3)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_1_HORIZONTAL_4 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_1_HORIZONTAL_4)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_2_HORIZONTAL_4 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_2_HORIZONTAL_4)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_3_HORIZONTAL_4 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_3_HORIZONTAL_4)
                self._resultMessage = "Succeeded"
                return true
            } else if scale == Sample.VARTICAL_4_HORIZONTAL_4 {
                try self._printer.setTemplateTextSize(.SII_PM_VARTICAL_4_HORIZONTAL_4)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to setTemplateTextSize"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextFontSample(_ font: Int32) -> Bool {
        do {
            if font == Sample.FONT_A {
                try self._printer.setTemplateTextFont(.SII_PM_FONT_A)
                self._resultMessage = "Succeeded"
                return true
            } else if font == Sample.FONT_B {
                try self._printer.setTemplateTextFont(.SII_PM_FONT_B)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to setTemplateTextFont"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextRegisteredFontSample(_ font: Int32) -> Bool {
        do {
            if font == Sample.FONT_STANDARD {
                try self._printer.setTemplateTextRegisteredFont(.SII_PM_FONT_STANDARD)
                self._resultMessage = "Succeeded"
                return true
            } else if font == Sample.FONT_OPTION {
                try self._printer.setTemplateTextRegisteredFont(.SII_PM_FONT_OPTION)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to setTemplateTextRegisteredFont"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextRightSpacingSample(_ spacing: Int32) -> Bool {
        do {
            try self._printer.setTemplateTextRightSpacing(spacing)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextColorSample(_ color: Int32) -> Bool {
        do {
            try self._printer.setTemplateTextColor(color)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateTextDataSample(_ text: String) -> Bool {
        do {
            try self._printer.setTemplateTextData(text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateQrCodeDataSample(_ mapID: Int32, _ moduleSize: ModuleSize, _ errorCorrection: ErrorCorrection, _ mode: QrDataMode, _ qrQuietZone: QrQuietZone, _ text: String) -> Bool {
        do {
            try self._printer.setTemplateQrCodeData(mapID, moduleSize: moduleSize, errorCorrection: errorCorrection, mode: mode, qrQuietZone: qrQuietZone, text: text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateQrCodeDataSample(_ mapID: Int32, _ text: String) -> Bool {
        do {
            try self._printer.setTemplateQrCodeData(mapID, text: text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func setTemplateBarcodeDataSample(_ mapID: Int32, _ text: String) -> Bool {
        do {
            try self._printer.setTemplateBarcodeData(mapID, text: text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func registerTemplateSample(_ templateID: Int32, _ label: String, _ fileName: String) -> Bool {
        do {
            try self._printer.registerTemplate(templateID, label: label, fileName: fileName)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func unregisterTemplateSample(_ templateID: Int32) -> Bool {
        do {
            try self._printer.unregisterTemplate(templateID)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func registerImageDataSample(_ imageID: Int32, _ label: String, _ fileName: String) -> Bool {
        do {
            try self._printer.registerImageData(imageID, label: label, fileName: fileName)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func unregisterImageDataSample(_ imageID: Int32) -> Bool {
        do {
            try self._printer.unregisterImageData(imageID)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func registerSlideDataSample(_ slideID: Int32, _ label: String, _ fileName: String) -> Bool {
        do {
            try self._printer.registerSlideData(slideID, label: label, fileName: fileName)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func unregisterSlideDataSample(_ slideID: Int32) -> Bool {
        do {
            try self._printer.unregisterSlideData(slideID)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func registerUserDefinedCharacterSample(_ fileName: String) -> Bool {
        do {
            try self._printer.registerUserDefinedCharacter(fileName)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func unregisterUserDefinedCharacterSample() -> Bool {
        do {
            try self._printer.unregisterUserDefinedCharacter()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func registerOptionFontSample(_ startCode: Int32, _ endCode: Int32, _ width: Int32, _ height: Int32, _ fileName: String) -> Bool {
        do {
            try self._printer.registerOptionFont(startCode, endCode: endCode, width: width, height: height, fileName: fileName)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func unregisterOptionFontSample() -> Bool {
        do {
            try self._printer.unregisterOptionFont()
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func controlMacroRegistrationSample(_ macroID: Int32, _ control: Int32) -> Bool {
        do {
            if control == Sample.MACRO_REGISTRATION_START {
                try self._printer.controlMacroRegistration(macroID, control: .SII_PM_MACRO_REGISTRATION_START)
                self._resultMessage = "Succeeded"
                return true
            } else if control == Sample.MACRO_REGISTRATION_REGIST {
                try self._printer.controlMacroRegistration(macroID, control: .SII_PM_MACRO_REGISTRATION_REGIST)
                self._resultMessage = "Succeeded"
                return true
            } else if control == Sample.MACRO_REGISTRATION_CLEAR {
                try self._printer.controlMacroRegistration(macroID, control: .SII_PM_MACRO_REGISTRATION_CLEAR)
                self._resultMessage = "Succeeded"
                return true
            } else {
                self._resultMessage = "Fail to controlMacroRegistration"
                return false
            }
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func getDisplayResponseSample(_ responseId: Int32) -> Bool {
        if responseId == SII_PM_DISPLAY_RESPONSE_REQUEST {
            return response_displayRequest()
        } else if responseId == SII_PM_DISPLAY_RESPONSE_USER_AREA {
            return response_displayUserarea()
        } else if responseId == SII_PM_DISPLAY_RESPONSE_TEMPLATE_ID_LIST {
            return response_displayTemplateID()
        } else if responseId == SII_PM_DISPLAY_RESPONSE_IMAGE_ID_LIST {
            return response_displayImageID()
        } else if responseId == SII_PM_DISPLAY_RESPONSE_SLIDE_ID_LIST {
            return response_displaySlideID()
        } else {
            self._resultMessage = "responseId invalid\n"
            return false
        }
    }
    
    static func getDisplayResponseSample(_ responseId: Int32, _ paramId: Int32) -> Bool {
        if responseId == SII_PM_DISPLAY_RESPONSE_TEMPLATE_LABEL {
            return response_displayTemplateLabel(paramId)
        } else if responseId == SII_PM_DISPLAY_RESPONSE_IMAGE_LABEL {
            return response_displayImageLabel(paramId)
        } else if responseId == SII_PM_DISPLAY_RESPONSE_SLIDE_LABEL {
            return response_displaySlideLabel(paramId)
        } else {
            self._resultMessage = "responseId invalid\n"
            return false
        }
    }
    
    static func response_displayRequest() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_REQUEST, param: 0x41, response: &val)
            self._resultMessage = String(format: "REQUEST:0x%02lX", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func response_displayUserarea() -> Bool {
        do {
            var val = [0] as [Int]
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_USER_AREA, response: &val)
            self._resultMessage = String(format: "USER_AREA:%ld", val[0])
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func response_displayTemplateID() -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_TEMPLATE_ID_LIST, responseArray: ret!)
            var resultIntArry = [Int32]()
            if 0 < ret.count {
                for i in 0..<ret.count {
                    resultIntArry.append(ret[i] as! Int32)
                }
            }
            var resultText = "TEMPLATE_ID:"
            for i in 0..<resultIntArry.count {
                resultText = resultText + String(resultIntArry[i]) + ", "
            }
            self._resultMessage = resultText
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func response_displayImageID() -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_IMAGE_ID_LIST, responseArray: ret!)
            var resultIntArry = [Int32]()
            if 0 < ret.count {
                for i in 0..<ret.count {
                    resultIntArry.append(ret[i] as! Int32)
                }
            }
            var resultText = "IMAGE_ID:"
            for i in 0..<resultIntArry.count {
                resultText = resultText + String(resultIntArry[i]) + ", "
            }
            self._resultMessage = resultText
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func response_displaySlideID() -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_SLIDE_ID_LIST, responseArray: ret!)
            var resultIntArry = [Int32]()
            if 0 < ret.count {
                for i in 0..<ret.count {
                    resultIntArry.append(ret[i] as! Int32)
                }
            }
            var resultText = "SLIDE_ID:"
            for i in 0..<resultIntArry.count {
                resultText = resultText + String(resultIntArry[i]) + ", "
            }
            self._resultMessage = resultText
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func response_displayTemplateLabel(_ templateID: Int32) -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_TEMPLATE_LABEL, param: templateID, responseArray: ret!)
            if ret.count == 1 {
                let text = String(describing: ret[0])
                self._resultMessage = "TEMPLATE_LABEL:\(text)"
            } else {
                self._resultMessage = "Not found"
            }
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func response_displayImageLabel(_ imageID: Int32) -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_IMAGE_LABEL, param: imageID, responseArray: ret!)
            if ret.count == 1 {
                let text = String(describing: ret[0])
                self._resultMessage = "IMAGE_LABEL:\(text)"
            } else {
                self._resultMessage = "Not found"
            }
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func response_displaySlideLabel(_ slideID: Int32) -> Bool {
        do {
            let ret: NSMutableArray! = NSMutableArray()
            try self._printer.getDisplayResponse(SII_PM_DISPLAY_RESPONSE_SLIDE_LABEL, param: slideID, responseArray: ret!)
            if ret.count == 1 {
                let text = String(describing: ret[0])
                self._resultMessage = "SLIDE_LABEL:\(text)"
            } else {
                self._resultMessage = "Not found"
            }
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }

    static func selectSmartLabelFileSample(_ filePath: String) -> Bool {
        do {
            try self._label.selectSmartLabelFile(filePath)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func replaceSmartLabelTextDataSample(_ mapID: Int32, _ text: String) -> Bool {
        do {
            try self._label.replaceSmartLabelTextData(mapID, text: text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func replaceSmartLabelBarcodeDataSample(_ mapID: Int32, _ text: String) -> Bool {
        do {
            try self._label.replaceSmartLabelBarcodeData(mapID, text: text)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func replaceSmartLabelImageDataSample(_ mapID: Int32, _ image: UIImage?) -> Bool {
        do {
            try self._label.replaceSmartLabelImageData(mapID, image: image)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func printSmartLabelImageDataSample() -> Bool {
        do {
            try self._printer.printSmartLabelImageData(_label.labelManager)
            self._resultMessage = "Succeeded"
            return true
        } catch let error as NSError {
            self._resultMessage = getErrorMessage(Int32(error.code))
            return false
        }
    }
    
    static func getErrorMessage(_ errorCode: Int32) -> String {
        switch errorCode {       
            case SII_PM_ERROR_ACCESS_DENIED:
                return "Exception:ACCESS_DENIED"
            case SII_PM_ERROR_SHARING_VIOLATION:
                return "Exception:SHARING_VIOLATION"
            case SII_PM_ERROR_PORT_NOT_OPENED:
                return "Exception:PORT_NOT_OPENED"
            case SII_PM_ERROR_DEVICE_NOT_CONNECTED:
                return "Exception:DEVICE_NOT_CONNECTED"
            case SII_PM_ERROR_OFFLINE:
                return "Exception:OFFLINE"
            case SII_PM_ERROR_EXTERNAL_DEVICE_NOT_CONNECTED:
                return "Exception:EXTERNAL_DEVICE_NOT_CONNECTED"
            case SII_PM_ERROR_DEVICE_INITIALIZE_FAILED:
                return "Exception:DEVICE_INITIALIZE_FAILED"
            case SII_PM_ERROR_DATA_SIZE_ZERO:
                return "Exception:DATA_SIZE_ZERO"
            case SII_PM_ERROR_OVER_MAX_DATA_SIZE:
                return "Exception:OVER_MAX_DATA_SIZE"
            case SII_PM_ERROR_DATA_SIZE_INVALID:
                return "Exception:DATA_SIZE_INVALID"
            case SII_PM_ERROR_ENCODE_FAILED:
                return "Exception:ENCODE_FAILED"
            case SII_PM_ERROR_TIMEOUT:
                return "Exception:TIMEOUT"
            case SII_PM_ERROR_FILE_NOT_FOUND:
                return "Exception:FILE_NOT_FOUND"
            case SII_PM_ERROR_FILE_USED:
                return "Exception:FILE_USED"
            case SII_PM_ERROR_FILE_INVALID:
                return "Exception:FILE_INVALID"
            case SII_PM_ERROR_LOW_MEMORY:
                return "Exception:LOW_MEMORY"
            case SII_PM_ERROR_OVER_MAX_IMAGE:
                return "Exception:OVER_MAX_IMAGE"
            case SII_PM_ERROR_LOGO_NOT_DEFINED:
                return "Exception:LOGO_NOT_DEFINED"
            case SII_PM_ERROR_LOW_USER_AREA:
                return "Exception:LOW_USER_AREA"
            case SII_PM_ERROR_LOW_EXTERNAL_RAM:
                return "Exception:LOW_EXTERNAL_RAM"
            case SII_PM_ERROR_NOT_REGISTERD:
                return "Exception:NOT_REGISTERD"
            case SII_PM_ERROR_NOT_UNREGISTERD:
                return "Exception:NOT_UNREGISTERD"
            case SII_PM_ERROR_INVALID_NO:
                return "Exception:INVALID_NO"
            case SII_PM_ERROR_OVER_STYLE_NUM:
                return "Exception:OVER_STYLE_NUM"
            case SII_PM_ERROR_INVALID_DATA:
                return "Exception:INVALID_DATA"
            case SII_PM_ERROR_PAGE_MODE_SPECIFIED:
                return "Exception:PAGE_MODE_SPECIFIED"
            case SII_PM_ERROR_PAGE_MODE_NOT_SPECIFIED:
                return "Exception:PAGE_MODE_NOT_SPECIFIED"
            case SII_PM_ERROR_LABEL_FILE_NOT_SELECTED:
                return "Exception:LABEL_FILE_NOT_SELECTED"
            case SII_PM_ERROR_GET_LABEL_IMAGE:
                return "Exception:GET_LABEL_IMAGE"
            case SII_PM_ERROR_INVALID_PARAM:
                return "Exception:INVALID_PARAM"
            default:
                return "Exception:Unknown error"
        }
    }

    static func printPageModeSample() -> Bool {
        var result = 0
        defer {
            if result == 0 {
                self._resultMessage = "Succeeded"
            } else {
                self._resultMessage = getErrorMessage(Int32(result))
            }
            _ = self.exitPageMode()
        }
        result = self.enterPageMode()
        if result != 0 {
            return false
        }
        result = self.setPageModeArea(0, 0, 576, 355)
        if result != 0 {
            return false
        }
        result = self.printPageModeRectangle(0, 0, 575, 344, LineStyle.SII_PM_LINESTYLE_THIN)
        if result != 0 {
            return false
        }
        result = self.printPageModeRectangle(7, 7, 567, 336, LineStyle.SII_PM_LINESTYLE_THIN)
        if result != 0 {
            return false
        }
        result = self.printPageModeLine(404, 11, 404, 334, LineStyle.SII_PM_LINESTYLE_THIN)
        if result != 0 {
            return false
        }
        result = self.printPageModeText(21, 47, "NO.123456789")
        if result != 0 {
            return false
        }
        result = self.printPageModeText(212, 330, "Date 2020-01-01")
        if result != 0 {
            return false
        }
        let fileName = Bundle.main.path(forResource: "TicketImage", ofType: "jpg")!
        result = self.printPageModeImageFile(10, 212, fileName, Dithering.SII_PM_DITHERING_DISABLE)
        if result != 0 {
            return false
        }
        result = self.setPageModeArea(404, 0, 163, 345)
        if result != 0 {
            return false
        }
        result = self.setPageModeDirection(Direction.SII_PM_DIRECTION_BOTTOM_TO_TOP)
        if result != 0 {
            return false
        }
        let barcodeSymbol = BarcodeSymbol.SII_PM_BARCODE_CODE128
        let data: Data? = "{B123456789".data(using: .utf8)
        let moduleSize = ModuleSize.SII_PM_BARCODE_MODULE_WIDTH_2
        let hriPosition = HriPosition.SII_PM_HRI_POSITION_ABOVE
        let hriFont = CharacterFont.SII_PM_FONT_A
        result = self.printPageModeBarcode(20, 132, barcodeSymbol, data, moduleSize, 80, hriPosition, hriFont)
        if result != 0 {
            return false
        }
        result = self.printPageMode(CuttingMethod.SII_PM_CUT_PARTIAL)
        if result != 0 {
            return false
        }
        return true
    }
    static func enterPageMode() -> Int {
        do {
            try self._printer.enterPageMode()
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageMode(_ cuttingMethod: CuttingMethod) -> Int {
        do {
            try self._printer.printPageMode(cuttingMethod)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func setPageModeArea(_ x: Int, _ y: Int, _ width: Int, _ height: Int) -> Int {
        do {
            try self._printer.setPageModeArea(x , y: y, width: width, height: height)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func setPageModeDirection(_ direction: Direction) -> Int {
        do {
            try self._printer.setPageModeDirection(direction)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func setPageModeLineSpacing(_ spacing: Int) -> Int {
        do {
            try self._printer.setPageModeLineSpacing(spacing)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeText(_ startX: Int, _ startY: Int, _ text: String) -> Int {
        do {
            try self._printer.printPageModeText(startX , startY: startY, text: text)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeTextEx(_ startX: Int, _ startY: Int, _ text: String, _ bold: CharacterBold, _ underline: CharacterUnderline, _ reverse: CharacterReverse, _ font: CharacterFont, _ scale: CharacterScale) -> Int {
        do {
            try self._printer.printPageModeTextEx(startX , startY: startY, text: text, bold: bold, underline: underline, reverse: reverse, font: font, scale: scale)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeBarcode(_ startX: Int, _ startY: Int, _ barcodeSymbol: BarcodeSymbol, _ text: String, _ moduleSize: ModuleSize, _ moduleHeight: Int, _ hriPosition: HriPosition, _ hriFont: CharacterFont) -> Int {
        do {
            try self._printer.printPageModeBarcode(startX , startY: startY, barcodeSymbol: barcodeSymbol, text: text, moduleSize: moduleSize, moduleHeight: moduleHeight, hriPosition: hriPosition, hriFont: hriFont)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeBarcode(_ startX: Int, _ startY: Int, _ barcodeSymbol: BarcodeSymbol, _ text: String, _ moduleSize: ModuleSize, _ moduleHeight: Int, _ hriPosition: HriPosition, _ hriFont: CharacterFont, _ nwRatio: NwRatio) -> Int {
        do {
            try self._printer.printPageModeBarcode(startX , startY: startY, barcodeSymbol: barcodeSymbol, text: text, moduleSize: moduleSize, moduleHeight: moduleHeight, hriPosition: hriPosition, hriFont: hriFont, nwRatio: nwRatio)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeBarcode(_ startX: Int, _ startY: Int, _ barcodeSymbol: BarcodeSymbol, _ data: Data?, _ moduleSize: ModuleSize, _ moduleHeight: Int, _ hriPosition: HriPosition, _ hriFont: CharacterFont) -> Int {
        do {
            try self._printer.printPageModeBarcode(startX , startY: startY, barcodeSymbol: barcodeSymbol, data: data, moduleSize: moduleSize, moduleHeight: moduleHeight, hriPosition: hriPosition, hriFont: hriFont)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModePDF417(_ startX: Int, _ startY: Int, _ text: String, _ errorCorrection: ErrorCorrection, _ row: Int, _ column: Int, _ moduleSize: ModuleSize, _ moduleHeight: Int) -> Int {
        do {
            try self._printer.printPageModePDF417(startX , startY: startY, text: text, errorCorrection: errorCorrection, row: row, column: column, moduleSize: moduleSize, moduleHeight: moduleHeight)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModePDF417(_ startX: Int, _ startY: Int, _ text: String, _ errorCorrection: ErrorCorrection, _ row: Int, _ column: Int, _ moduleSize: ModuleSize, _ moduleHeight: Int, _ pdf417Symbol: Pdf417Symbol) -> Int {
        do {
            try self._printer.printPageModePDF417(startX , startY: startY, text: text, errorCorrection: errorCorrection, row: row, column: column, moduleSize: moduleSize, moduleHeight: moduleHeight, pdf417Symbol: pdf417Symbol)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeQRcode(_ startX: Int, _ startY: Int, _ text: String, _ errorCorrection: ErrorCorrection, _ moduleSize: ModuleSize, _ model: QrModel) -> Int {
        do {
            try self._printer.printPageModeQRcode(startX , startY: startY, text: text, errorCorrection: errorCorrection, moduleSize: moduleSize, model: model)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeQRcode(_ startX: Int, _ startY: Int, _ text: String, _ errorCorrection: ErrorCorrection, _ moduleSize: ModuleSize) -> Int {
        do {
            try self._printer.printPageModeQRcode(startX , startY: startY, text: text, errorCorrection: errorCorrection, moduleSize: moduleSize)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeDataMatrix(_ startX: Int, _ startY: Int, _ text: String, _ dataMatrixModule: DataMatrixModule, _ moduleSize: ModuleSize) -> Int {
        do {
            try self._printer.printPageModeDataMatrix(startX , startY: startY, text: text, dataMatrixModule: dataMatrixModule, moduleSize: moduleSize)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeMaxiCode(_ startX: Int, _ startY: Int, _ text: String, _ maxiCodeMode: MaxiCodeMode) -> Int {
        do {
            try self._printer.printPageModeMaxiCode(startX , startY: startY, text: text, maxiCodeMode: maxiCodeMode)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeGS1DataBarStacked(_ startX: Int, _ startY: Int, _ text: String, _ moduleSize: ModuleSize) -> Int {
        do {
            try self._printer.printPageModeGS1DataBarStacked(startX , startY: startY, text: text, moduleSize: moduleSize)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeGS1DataBarStackedOmnidirectional(_ startX: Int, _ startY: Int, _ text: String, _ moduleHeight: Int, _ moduleSize: ModuleSize) -> Int {
        do {
            try self._printer.printPageModeGS1DataBarStackedOmnidirectional(startX , startY: startY, text: text, moduleHeight: moduleHeight, moduleSize: moduleSize)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeGS1DataBarExpandedStacked(_ startX: Int, _ startY: Int, _ text: String, _ column: Int, _ moduleSize: ModuleSize) -> Int {
        do {
            try self._printer.printPageModeGS1DataBarExpandedStacked(startX , startY: startY, text: text, column: column, moduleSize: moduleSize)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeAztecCode(_ startX: Int, _ startY: Int, _ text: String, _ layer: Int, _ errorCorrection: Int, _ moduleSize: ModuleSize, _ aztecSymbol: AztecSymbol) -> Int {
        do {
            try self._printer.printPageModeAztecCode(startX , startY: startY, text: text, layer: layer, errorCorrection: errorCorrection, moduleSize: moduleSize, aztecSymbol: aztecSymbol)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func sendPageModeBinary(_ data: Data?) -> Int {
        do {
            try self._printer.sendPageModeBinary(data)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeImageFile(_ startX: Int, _ startY: Int, _ fileName: String, _ dithering: Dithering) -> Int {
        do {
            try self._printer.printPageModeImageFile(startX , startY: startY, fileName: fileName, dithering: dithering)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeLogo(_ startX: Int, _ startY: Int, _ logoId: String) -> Int {
        do {
            try self._printer.printPageModeLogo(startX , startY: startY, logoId: logoId)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeRectangle(_ startX: Int, _ startY: Int, _ endX: Int, _ endY: Int, _ lineStyle: LineStyle) -> Int {
        do {
            try self._printer.printPageModeRectangle(startX , startY: startY, endX: endX, endY: endY, lineStyle: lineStyle)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func printPageModeLine(_ startX: Int, _ startY: Int, _ endX: Int, _ endY: Int, _ lineStyle: LineStyle) -> Int {
        do {
            try self._printer.printPageModeLine(startX , startY: startY, endX: endX, endY: endY, lineStyle: lineStyle)
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
    static func exitPageMode() -> Int {
        do {
            try self._printer.exitPageMode()
        } catch let error as NSError {
            return error.code
        }
        return 0
    }
}
